<?php
/**
 * The template for displaying the footer
 *
 * Contains the closing of the #content div and all content after.
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package Ignis
 */

?>
		</div><!-- .container -->
	</div><!-- #content -->


	<footer id="colophon" class="site-footer clearfix" role="contentinfo">
		<?php do_action( 'ignis_footer' ); ?> 
	</footer><!-- #colophon -->
</div><!-- #page -->

<?php wp_footer(); ?>

</body>
</html>
