<?php
/**
 * Home Page sections
 *
 * This is the template that includes all the other files for home page sections
 *
 * @package Theme Palace
 * @subpackage Mega Blog
 * @since Mega Blog 1.0.0
 */

// message section
require get_template_directory() . '/inc/sections/message.php';

// featured section
require get_template_directory() . '/inc/sections/featured.php';

// recent section
require get_template_directory() . '/inc/sections/recent.php';

// popular section
require get_template_directory() . '/inc/sections/popular.php';

// contact section
require get_template_directory() . '/inc/sections/contact.php';
