/* 
    Document   : orange
    Created on : Jul 6, 2014, 2:28:39 AM
    Author     : Bilal
    Description:
        Purpose of the stylesheet follows.
*/
a,a:visited {
  color: #DC838D;
}
a:hover{
    color: #E05867;
}
.primary-color{ color: #DC838D;}
#site-cta .site-cta .fa.hover{
    background: #DC838D;    
}
a.button-primary {
    background-color: #DC838D;
    color: #ffffff;
}
.button-primary:hover,
.button-primary:focus,
.button-primary:active,
.button-primary.active,
.open .dropdown-toggle.button-primary {
  background-color: #E05867;
}
fieldset[disabled] .button-primary.active {
  background-color: #DC838D;
}

#main-heading,
#secondary-heading{
    background: #DC838D;
    color: #fff;
}
.button-primary .badge {
  color: #DC838D;
}
.button-link {
  color: #DC838D;
}
.sc-primary-color{ color: #DC838D;}
.sc-primary-border{ border-color: #DC838D;}
.site-branding .search-bar .search-field:focus{
    border-bottom: 1px solid #DC838D;
}
.icon404{
    color: #DC838D;
}
.nav-menu > li a:hover{
    color: #DC838D;
}
.scroll-top:hover{
    border-color: #DC838D;
}

ul.social-icons li a:hover{
    background: #DC838D;
}
.smartcat_team_member:hover h4{
    color: #DC838D;
    
}
.smartcat_team_member:hover img{
    -webkit-filter: grayscale(0%);
    -moz-filter: grayscale(0%);
    filter: grayscale(0%);
}
#site-toolbar .row .social-bar a:hover{
    background: #DC838D;
}
#site-navigation.main-navigation li a:hover,
#site-navigation.main-navigation li.current_page_item a{
    color: #DC838D;
}
#site-cta .site-cta .fa{
    border: 2px solid #DC838D;
    color: #DC838D;
}
@media(max-width: 600px){
    .nav-menu > li.current_page_item a{
        color: #DC838D;
    }      
}

#footer-callout{
    background: #DC838D;
}