@font-face {
  font-family: 'fontello';
  src: url('../fonts/fontello.eot?5381655');
  src: url('../fonts/fontello.eot?5381655#iefix') format('embedded-opentype'),
       url('../fonts/fontello.woff2?5381655') format('woff2'),
       url('../fonts/fontello.woff?5381655') format('woff'),
       url('../fonts/fontello.ttf?5381655') format('truetype'),
       url('../fonts/fontello.svg?5381655#fontello') format('svg');
  font-weight: normal;
  font-style: normal;
}
 
[class^="icon-"]:before, [class*=" icon-"]:before {
  font-family: "fontello";
  font-style: normal;
  font-weight: normal;
  speak: none;
 
  display: inline-block;
  text-decoration: inherit;
  width: 1em;
  text-align: center;
  font-variant: normal;
  text-transform: none;
  line-height: 1em;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
}
 
.icon-right-open-big:before { content: '\e800'; }
.icon-left-open-big:before { content: '\e801'; }
.icon-mail:before { content: '\e802'; }
.icon-angle-left:before { content: '\f104'; }
.icon-angle-right:before { content: '\f105'; }
.icon-angle-up:before { content: '\f106'; }
.icon-angle-down:before { content: '\f107'; }