/**
 * Colors
 */
/**
 * Deprecated colors.
 * Please avoid using these.
 */
/**
 * Breakpoints & Media Queries
 */
/**
 * Colors
 */
/**
 * Deprecated colors.
 * Please avoid using these.
 */
/**
 * Fonts & basic variables.
 */
/**
 * Grid System.
 * https://make.wordpress.org/design/2019/10/31/proposal-a-consistent-spacing-system-for-wordpress/
 */
/**
 * Dimensions.
 */
/**
 * Shadows.
 */
/**
 * Editor widths.
 */
/**
 * Block UI.
 */
/**
 * Border radii.
 */
/**
 * Breakpoint mixins
 */
/**
 * Long content fade mixin
 *
 * Creates a fading overlay to signify that the content is longer
 * than the space allows.
 */
/**
 * Focus styles.
 */
/**
 * Applies editor left position to the selector passed as argument
 */
/**
 * Styles that are reused verbatim in a few places
 */
/**
 * Allows users to opt-out of animations via OS-level preferences.
 */
/**
 * Reset default styles for JavaScript UI based pages.
 * This is a WP-admin agnostic reset
 */
/**
 * Reset the WP Admin page styles for Gutenberg-like pages.
 */
:root {
  --wp-admin-theme-color: #007cba;
  --wp-admin-theme-color-darker-10: #006ba1;
  --wp-admin-theme-color-darker-20: #005a87; }

/**
 * Editor Normalization Styles
 *
 * These are only output in the editor, but styles here are prefixed .editor-styles-wrapper and affect the theming
 * of the editor by themes.
 * Why do these exist? Why not rely on browser defaults?
 * These styles are necessary so long as CSS can bleed from the wp-admin into the editing canvas itself.
 * Let's continue working to refactor these away, whether through Shadow DOM or better scoping of upstream styles.
 */
body {
  font-family: "Noto Serif", serif;
  font-size: 16px;
  line-height: 1.8;
  color: #1e1e1e;
  padding: 10px; }

.block-editor-block-list__layout.is-root-container > .wp-block[data-align="full"] {
  margin-left: -10px;
  margin-right: -10px; }

/* Headings */
h1 {
  font-size: 2.44em; }

h2 {
  font-size: 1.95em; }

h3 {
  font-size: 1.56em; }

h4 {
  font-size: 1.25em; }

h5 {
  font-size: 1em; }

h6 {
  font-size: 0.8em; }

h1,
h2,
h3 {
  line-height: 1.4; }

h4 {
  line-height: 1.5; }

h1 {
  margin-top: 0.67em;
  margin-bottom: 0.67em; }

h2 {
  margin-top: 0.83em;
  margin-bottom: 0.83em; }

h3 {
  margin-top: 1em;
  margin-bottom: 1em; }

h4 {
  margin-top: 1.33em;
  margin-bottom: 1.33em; }

h5 {
  margin-top: 1.67em;
  margin-bottom: 1.67em; }

h6 {
  margin-top: 2.33em;
  margin-bottom: 2.33em; }

h1,
h2,
h3,
h4,
h5,
h6 {
  color: inherit; }

p {
  font-size: inherit;
  line-height: inherit;
  margin-top: 28px;
  margin-bottom: 28px; }

ul,
ol {
  margin-bottom: 28px;
  padding-left: 1.3em;
  margin-left: 1.3em; }
  ul ul,
  ul ol,
  ol ul,
  ol ol {
    margin-bottom: 0; }
  ul li,
  ol li {
    margin-bottom: initial; }

ul {
  list-style-type: disc; }

ol {
  list-style-type: decimal; }

ul ul,
ol ul {
  list-style-type: circle; }

.wp-align-wrapper {
  max-width: 580px; }
  .wp-align-wrapper > .wp-block, .wp-align-wrapper.wp-align-full {
    max-width: none; }
  .wp-align-wrapper.wp-align-wide {
    max-width: 1100px; }

a {
  transition: none; }

code,
kbd {
  padding: 0;
  margin: 0;
  background: inherit;
  font-size: inherit;
  font-family: monospace; }
