/*--------------------------------------------------------------
1.0 Product Grid
--------------------------------------------------------------*/

.woocommerce .main-container,
.woocommerce-page .main-container {
    float: none;
    width: 100% !important;
}

.woocommerce div.product div.images .flex-control-thumbs li {
    width: calc((100% - 15px) / 4 - 1px);
    width: -width-calc((100% - 15px) / 4 - 1px);
    margin-top: 5px;
    margin-right: 5px;
}

.woocommerce div.product div.images .flex-control-thumbs li:nth-child(4n) {
    margin-right: 0;
}

.woocommerce span.onsale {
    top: 7px !important;
    left: 7px !important;
    right: auto !important;
    min-height: 0;
    min-width: 0;
    padding: 5px 10px;
    margin: 0 !important;
    line-height: 1;
    font-weight: 400;
    -webkit-border-radius: 0;
    border-radius: 0;
}

.woocommerce ul.products li.product .price {
    margin-bottom: 2px;
}
.woocommerce ul.products li.product .price del {
    display: inline-block;
    margin-right: 5px;
}

a.added_to_cart.wc-forward {
    display: none !important;
}

.woocommerce a.button.loading::after,
.woocommerce button.button.loading::after,
.woocommerce input.button.loading::after,
.woocommerce #respond input#submit.loading::after {
    display: none !important;
}

/* Rating */
.woocommerce .star-rating {
    width: 100px !important;
}

.woocommerce .products .star-rating {
    margin-bottom: 0;
}

.woocommerce ul.products li.product .star-rating {
    height: 14px;
    line-height: 1.3;
}

.woocommerce ul.products li.product .star-rating span,
.woocommerce ul.products li.product .star-rating::before {
    left: 8px;
}

.woocommerce .star-rating::before {
    content: '\73\00a0\73\00a0\73\00a0\73\00a0\73\00a0';
}

.woocommerce .star-rating span::before {
    content: '\53\00a0\53\00a0\53\00a0\53\00a0\53';
}

.woocommerce div.product select {
    -webkit-appearance: none;
    -moz-appearance: none;
}


/*--------------------------------------------------------------
2.0 Product Single
--------------------------------------------------------------*/

.product_meta > span {
    display: block;
}

.woocommerce div.product form.cart .variations td.label {
    width: 15%;
    line-height: 40px;
    padding-right: 0;
}

.woocommerce div.product form.cart .variations select {
    padding: 10px;
    width: 40%;
    min-width: 40%;
    margin-bottom: 15px;
}

.woocommerce .quantity .qty {
    padding: 9px 3px 10px 10px;
}

/* Tabs */
.woocommerce div.product .woocommerce-tabs ul.tabs {
    padding-left: 5px;
}

.woocommerce div.product .woocommerce-tabs ul.tabs li {
    margin-right: 0;
    border-bottom: 0;
    -webkit-border-radius: 0;
    border-radius: 0;
}

.woocommerce div.product .woocommerce-tabs ul.tabs li a {
    font-weight: 400;
}

.woocommerce div.product .woocommerce-tabs ul.tabs li::before,
.woocommerce div.product .woocommerce-tabs ul.tabs li::after,
.woocommerce div.product .woocommerce-tabs ul.tabs li.active::before,
.woocommerce div.product .woocommerce-tabs ul.tabs li.active::after {
    border: 0;
    box-shadow: none;
}

#reviews .comment-form-author,
#reviews .comment-form-email {
    float: none;
    width: 55% !important;
}

#reviews .comment-form-author input,
#reviews .comment-form-email input {
    width: 100%;
}

#reviews #reply-title {
    margin-top: 15px;
}


/*--------------------------------------------------------------
3.0 Inputs, Buttons
--------------------------------------------------------------*/

.woocommerce-page #page-content textarea,
.woocommerce-page #page-content select,
.woocommerce-page #page-content input[type="tel"],
.woocommerce-page #page-content input[type="text"],
.woocommerce-page #page-content input[type="email"],
.woocommerce-page #page-content input[type="password"] {
    padding: 10px;
    border-width: 1px;
    border-style: solid;
}

#page-content .woocommerce input[type="number"],
.woocommerce #page-content input[type="number"] {
    border-width: 1px;
    border-style: solid;
}

/* Checkout */
.woocommerce form .form-row .required {
    border: 0;
    text-decoration: none;
    cursor: default;
}

.select2-container--default .select2-selection--single {
    height: 44px;
    border-radius: 0;
    -webkit-border-radius: 0;
}

.select2-container--default .select2-selection--single .select2-selection__rendered {
    line-height: 44px;
}

.select2-container--default .select2-selection--single .select2-selection__arrow {
    top: 10px;
}

.woocommerce form.checkout_coupon,
.woocommerce form.login,
.woocommerce form.register {
    border-radius: 0;
    -webkit-border-radius: 0;
}

.woocommerce form .form-row-first,
.woocommerce form .form-row-last {
    width: 100% !important;
}

/* My Account */
.woocommerce form .form-row label.inline {
    display: block;
    margin-top: 5px;
}

.woocommerce .woocommerce-MyAccount-navigation-link {
  list-style: none;
  padding: 13px 0;
  border-bottom: 1px solid;
}

.woocommerce-MyAccount-navigation > ul {
  padding: 0;
}

.woocommerce-account .woocommerce-MyAccount-navigation {
  width: 25%;
}

.woocommerce-account .woocommerce-MyAccount-content {
  width: 72%;
}

.woocommerce address {
  line-height: 32px;
  margin-bottom: 30px;
}

.woocommerce-Addresses {
  margin-top: 20px;
}

.woocommerce-account fieldset {
    border-width: 1px;
    border-style: solid;
    margin: 21px 0;
    padding: 16px;
}


/*--------------------------------------------------------------
4.0 Main CSS
--------------------------------------------------------------*/

.woocommerce #page-content ul.products li.product .button,
#page-content .woocommerce ul.products li.product .button {
    text-transform: uppercase;
    padding: 13px 20px;
    font-weight: bold;
}

.woocommerce ul.products li.product .woocommerce-loop-category__title,
.woocommerce ul.products li.product .woocommerce-loop-product__title,
.woocommerce ul.products li.product h3 {
    padding: 0;
    margin: 0;
}

.woocommerce-result-count {
    margin-bottom: 30px!important;
}

.woocommerce div.product .product_title {
    margin-bottom: 10px;
}

.woocommerce div.product p.price,
.woocommerce div.product span.price {
    font-size: inherit;
    margin-bottom: 19px;
}

.woocommerce-product-details__short-description {
    margin-bottom: 25px;
}

.woocommerce div.product form.cart .variations {
    margin-bottom: 22px;
}

.product_meta > span {
    margin-bottom: 4px;
}

.woocommerce-variation-price {
    margin-bottom: 9px;
}

.woocommerce div.product .woocommerce-product-rating {
    margin-bottom: 10px;
}

.woocommerce div.product form.cart .group_table td {
    vertical-align: middle;
}

.woocommerce div.product .woocommerce-tabs ul.tabs li {
    padding: 0;
}

.woocommerce div.product .woocommerce-tabs ul.tabs {
    margin-bottom: 25px;
}

.woocommerce div.product .woocommerce-tabs ul.tabs li a {
    padding: 10px 22px;
}

.upsells.products > h2,
.crosssells.products > h2,
.related.products > h2 {
    text-align: center;
    margin-bottom: 27px;
    font-weight: 600;
    text-transform: uppercase;
    line-height: 1;
}

.woocommerce div.product .woocommerce-tabs .panel > h2,
.woocommerce #reviews #comments h2,
.woocommerce .cart-collaterals .cross-sells > h2,
.woocommerce-page .cart-collaterals .cross-sells > h2,
.woocommerce .cart-collaterals .cart_totals > h2,
.woocommerce-page .cart-collaterals .cart_totals > h2,
.woocommerce-billing-fields > h3,
.woocommerce-shipping-fields > h3,
#order_review_heading,
#customer_login h2,
.woocommerce-Address-title h3,
.woocommerce-order-details__title,
.woocommerce-customer-details h2,
.woocommerce-columns--addresses h3 {
    margin-bottom: 15px;
    line-height: 1.5;
    text-transform: uppercase;
}

.woocommerce #reply-title {
    margin-bottom: 5px;
    display: inline-block;
}

.woocommerce .comment-form-rating label {
    margin-bottom: 4px;
}

.woocommerce #review_form #respond textarea {
    height: 300px;
}

.woocommerce-Reviews .comment_container {
    overflow: hidden;
    padding: 0px 0 55px;
    margin-bottom: 34px;
    border-bottom-style: solid;
    border-bottom-width: 1px;
}

.woocommerce #reviews #comments ol.commentlist li .comment-text {
    margin-left: 77px;
    border: none;
    padding: 0;
}

.woocommerce #reviews #comments ol.commentlist li img.avatar {
    width: 60px;
    padding: 0;
    border: none;
    border-radius: 50%;
    -webkit-border-radius: 50%;
}

.woocommerce-Reviews .woocommerce-review__author {
    font-weight: 600;
    text-transform: uppercase;
    display: block;
}

.woocommerce-Reviews .woocommerce-review__dash {
    display: none;
}

.woocommerce-Reviews .woocommerce-review__published-date {
    display: block;
    margin-bottom: 7px;
    text-transform: uppercase;
}

.woocommerce #reviews #comments ol.commentlist li .comment-text p {
    margin: 0;
}

.woocommerce #reviews #comments .woocommerce-Reviews-title {
    margin-bottom: 20px;
}

.woocommerce div.product .woocommerce-tabs .panel {
    margin-bottom: 40px;
}

.woocommerce table.shop_table th {
    padding: 14px 12px;
}

.woocommerce table.shop_table tr:last-child td {
    padding: 20px 18px;
}

.woocommerce #content table.cart td.actions .input-text,
.woocommerce table.cart td.actions .input-text,
.woocommerce-page #content table.cart td.actions .input-text,
.woocommerce-page table.cart td.actions .input-text {
    width: 130px;
}

#add_payment_method table.cart td.actions .coupon .input-text,
.woocommerce-cart table.cart td.actions .coupon .input-text,
.woocommerce-checkout table.cart td.actions .coupon .input-text {
    margin-right: 10px;
}

.woocommerce table.shop_table {
    margin-bottom: 60px;
}

.woocommerce-error,
.woocommerce-info,
.woocommerce-message {
    margin-bottom: 48px;
}

.woocommerce-message {
    line-height: 40px;
}

.woocommerce-info {
    line-height: 29px;
}

.woocommerce-error {
    line-height: 28px;
}

.woocommerce-error li,
.woocommerce-info li,
.woocommerce-message li {
    line-height: 26px;
    padding-left: 35px !important;
}

.woocommerce-billing-fields {
    margin-bottom: 60px;
}

.woocommerce .woocommerce-checkout-review-order table.shop_table {
    width: 48%;
    float: left;
}

.woocommerce-checkout-review-order .woocommerce-checkout-payment {
    float: right;
    width: 48%;
}

.woocommerce .woocommerce-checkout-review-order table.shop_table th,
.woocommerce .woocommerce-checkout-review-order table.shop_table td {
    width: 50%;
    padding: 17px 25px;
}

.woocommerce form .form-row-last,
.woocommerce-page form .form-row-last {
    float: left;
}

.woocommerce form.login,
.woocommerce form.register,
.woocommerce form.checkout_coupon {
    margin-top: 0;
}

.woocommerce ul.products li.product,
.woocommerce-page ul.products li.product {
    margin: 0 2% 2.992em 0;
    width: 32% !important;
    text-align: center;
}

.woocommerce ul.products li.last,
.woocommerce-page ul.products li.last {
    margin-right: 0 !important;
}

.woocommerce ul.products li.product .star-rating {
    margin-left: auto;
    margin-right: auto;
}

.woocommerce #page-content ul.products li.product .button,
#page-content .woocommerce ul.products li.product .button {
    background-color: transparent!important;
    border-style: solid;
    border-width: 1px;
    border-radius: 0;
    -webkit-border-radius: 0;
}

#page-content .woocommerce input.button,
#page-content .woocommerce a.button,
#page-content .woocommerce a.button.alt,
#page-content .woocommerce button.button.alt,
#page-content .woocommerce input.button.alt,
#page-content .woocommerce #respond input#submit.alt,
.woocommerce #page-content .widget_price_filter .button,
.woocommerce #page-content .woocommerce-message .button,
.woocommerce #page-content a.button.alt,
.woocommerce #page-content button.button.alt,
.woocommerce #page-content #respond input#submit,
.woocommerce #page-content .woocommerce-message .button,
.woocommerce-page #page-content .woocommerce-message .button,
.woocommerce #respond input#submit,
.woocommerce a.button,
.woocommerce button.button,
.woocommerce input.button,
.woocommerce button.button:disabled,
.woocommerce button.button:disabled[disabled] {
    width: auto;
    padding: 14px;
    border: none;
    border-radius: 0;
    -webkit-border-radius: 0;
    font-weight: 600;
    text-transform: uppercase;
    cursor: pointer;
}

.woocommerce-ordering select {
    width: 100%;
    padding: 10px;
    border-width: 1px;
    border-style: solid;
}

.woocommerce table.shop_table {
    border-radius: 0;
    -webkit-border-radius: 0;
}

.woocommerce table tr,
.woocommerce table th,
.woocommerce table td {
    border: none;
}
.woocommerce a.remove:hover {
    background: none !important;
    text-decoration: none;
}

.woocommerce form .form-row .required {
    font-weight: 400;
}

.woocommerce-cart #payment div.payment_box::before,
#add_payment_method #payment div.payment_box::before,
.woocommerce-checkout #payment div.payment_box::before {
    top: -0.95em;
    border-right-color: transparent !important;
    border-left-color: transparent !important;
    border-top-color: transparent !important;
}

.woocommerce table.shop_table td {
    padding: 13px 12px;
}

.woocommerce .widget_layered_nav ul li,
.woocommerce .widget_product_categories ul li {
    float: left;
    width: 100%;
    text-align: right;
}

.woocommerce .widget_layered_nav ul li a,
.woocommerce .widget_product_categories ul li a {
    float: left;
    overflow: hidden;
}

.woocommerce .widget_layered_nav .children li {
    padding-left: 10px;
    border-top-width: 1px;
    border-style: dotted; 
}

.woocommerce .widget_layered_nav > ul > li,
.woocommerce .widget_product_categories > ul > li {
    line-height: 1.6;
    padding: 10px 0;
    border-bottom-width: 1px;
    border-bottom-style: dotted;
}

/* css chrome */
.woocommerce .widget_rating_filter ul li {
    padding-bottom: 10px;
    text-align: right;
}

.woocommerce .widget_rating_filter ul li .star-rating {
    display: inline-block;
    float: left;
}

.woocommerce ul.cart_list li, .woocommerce ul.product_list_widget li {
    padding-top: 0;
    padding-bottom: 15px;
}

.woocommerce .product_list_widget .quantity,
.woocommerce .widget_products .amount,
.woocommerce .widget_price_filter .price_slider_amount,
.woocommerce .widget_recently_viewed_products .amount,
.woocommerce .widget_top_rated_products .amount,
.woocommerce .widget_recent_reviews .reviewer {
    line-height: 1.7;
}

.woocommerce .widget_shopping_cart .total,
.woocommerce.widget_shopping_cart .total {
    border-top: 1px solid;
    padding: 10px 0;
    margin-bottom: 0;
}

.woocommerce .widget_shopping_cart .buttons a, .woocommerce.widget_shopping_cart .buttons a {
    margin-right: 10px;
}

.woocommerce ul.cart_list li img, .woocommerce ul.product_list_widget li img {
    width: 48px;
}

.woocommerce .widget_recent_reviews .star-rating, .woocommerce .widget_top_rated_products .star-rating {
    margin: 5px 0 3px 0;
}

.woocommerce .widget_recent_reviews li  img {
    width: 64px !important;
}

/* Price Filter */
.woocommerce .widget_price_filter .ui-slider .ui-slider-range,
.woocommerce .widget_price_filter .ui-slider .ui-slider-handle {
    background-color: #333;
}

.woocommerce .widget_price_filter .price_slider_wrapper .ui-widget-content {
    background-color: rgba(161, 161, 161, 0.34);
}

.woocommerce .widget_price_filter .ui-slider {
    margin-top: 22px;
}

.woocommerce .widget_price_filter .ui-slider-horizontal {
    height: 4px;
}

.woocommerce .widget_price_filter .ui-slider .ui-slider-handle {
    top: -3px;
    width: 10px;
    height: 10px;
}

.widget_recently_viewed_products > ul {
    margin-top: 20px !important;
}

.woocommerce .loader::before {
    display: none !important;
}


/*--------------------------------------------------------------
5.0 Spacing
--------------------------------------------------------------*/

.woocommerce ul.products li.product a img {
    margin: 0px 0 19px;
    box-shadow: none;
}

.woocommerce ul.products li.product .button {
    margin-top: 12px;
}

.woocommerce-result-count {
    margin-bottom: 32px!important;
}

.woocommerce .woocommerce-ordering {
    margin: 0 0 1em;
    margin-top: -30px;
}

.woocommerce-products-header__title {
    margin-bottom: 4px!important;
}

.woocommerce div.product form.cart {
    margin-bottom: 28px;
}

.woocommerce div.product p.price,
.woocommerce div.product span.price {
    margin-bottom: 19px;
}

.woocommerce div.product .woocommerce-tabs ul.tabs {
    margin-bottom: 24px;
}

.woocommerce p.stars a {
    margin-right: 2px;
}

.woocommerce #review_form #respond .form-submit {
    margin-top: 25px;
}

.woocommerce span.onsale {
    padding: 6px 11px;
}