/* Options Framework Admin Styles */
.width30{
    width: 25%;
}
.width50{ width: 50%;}
.left{ float: left; }
.center{ text-align: center;}
.ml2p{ margin-left: 2%;}


#wpbody-content .metabox-holder{
    padding-top: 0;
}
#wpbody-content .smartcat-icon{
    width: 100%;
}
#setting-error-save_options{
    margin: 0;
    padding: 0;
}
#setting-error-save_options p{
    margin: 0;
    box-shadow: 0;
    -webkit-box-shadow: 0;
    -moz-box-shadow: 0;
    
}

.sc-tab-option{
    width: 100%;
    
    color: #ffffff;
    font-size: 22px;
    margin-bottom: 10px;
    text-align: center;
}
.sc-tab-option a{
    background: #178DC4;
    display: block;
    padding: 10px;
    color: #ffffff;
    text-decoration: none;
    box-shadow: 1px 1px 3px #333333;
    -webkit-box-shadow: 1px 1px 3px #333333;
    -moz-box-shadow: 1px 1px 3px #333333;
    transition: 0.2s all ease-in-out;
    -moz-transition: 0.2s all ease-in-out;
    -webkit-transition: 0.2s all ease-in-out;
    text-shadow: 1px 1px #000;
}
.sc-tab-option a:hover{
    background: #313545;
}

.nav-tab-active:hover{
    /*background: url('../../images/menu-bg.png');*/
    
}


h2.nav-tab-wrapper{
    border: 0;
    padding-left: 0;
    overflow: hidden;
}

h2 .nav-tab:focus{
    outline: none;
}
.nav-tab-active, .nav-tab-active:hover{
    border-bottom: 0;
}
h2 .nav-tab{
    outline: none;
    float: left;
    height: 70px;
    width: 90px;
    text-align: center;
    border: solid 1px rgba(0, 0, 0, 0.4);
    box-shadow: inset 0px 0px 1px 1px rgba(255,255,255,0.05);
    border-top: none;
    margin: 0px;
    list-style-type: none;
    box-sizing: border-box;
    -moz-box-sizing: border-box;
    -webkit-box-sizing: border-box;
    /*background-image: url('../../images/menu-bg.png');*/
    color: #fff;
    font-size: 14px;
    /*padding-top: 20px;*/
    background: #313545;
}
h2 .nav-tab:hover{
    background: #178DC4;
    color: #fff;
}
.nav-tab.nav-tab-active{
    color: #fff;
    background: #178DC4;
}

.nav-tab-wrapper{
    
/*    width: 600px;
    height: 200px;*/
    
}
#optionsframework h4.heading{
    color: #ffffff;
}
#optionsframework {
    width:70%;
    float: left;
    background: #313545;
    border: 0;
}
@media (max-width: 650px){
    #optionsframework{
        width: 100%;
    }
}
#optionsframework label{
    color: #A8A8A8;
}
#optionsframework h3 {
	cursor: default;
        font-size: 20px;
	/*background:  url('../../images/menu-bg.png');*/
	border: 0;
        color: #ffffff;
}
#optionsframework p {
	margin-bottom:0;
	padding-bottom:10px;
}
#optionsframework .section {
	padding:10px 10px 0;
}
#optionsframework .group {
	padding-bottom:40px;
}
#optionsframework .section .controls {
	float: left;
	min-width:350px;
	width: 54%;
	padding-right:2%;
}
#optionsframework .section .explain {
	max-width:38%;
	float: left;
	font-size: 12px;
	line-height:16px;
	color: #A8A8A8;
}
#optionsframework .section-checkbox .controls {
	width: 98%;
}
#optionsframework .section-checkbox .explain {
	max-width:94%;
}
#optionsframework .controls input[type=text] {
	width:100%;
        /*background: #404040;*/
        /*color: #C2C2C2;*/
}
#optionsframework .controls input[type=text].wp-color-picker {
    width: 65px;
}
#optionsframework .controls select, #optionsframework .controls textarea {
	margin-bottom:10px;
	width:100%;
}
#optionsframework .section-radio label, #optionsframework .section-multicheck label {
	float:left;
	max-width:90%;
	line-height: 16px;
	margin-bottom: 5px;
}
#optionsframework input.checkbox, #optionsframework input.of-radio {
	margin: 0 10px 5px 0;
	float:left;
	clear:both;
}
#optionsframework .section-typography .controls {
	float:none;
	width:auto;
}
#optionsframework .section-typography .explain {
	float:none;
	width:auto;
}
#optionsframework .controls .of-typography-size {
	width:80px;
	float:left
}
#optionsframework .controls .of-typography-unit {
	width:50px;
	margin-left:5px;
	float:left
}
#optionsframework .controls .of-typography-face {
	width:100px;
	margin-left:5px;
	float:left
}
#optionsframework .controls .of-typography-style {
	width:80px;
	margin-left:5px;
	margin-right:5px;
	float:left
}
#optionsframework .section-typography .wp-picker-container {
	margin-top:2px;
}
#optionsframework .of-background-properties {
	clear:both;
	margin-top: 18px;
}
#optionsframework .controls .of-background-repeat {
	width:125px;
	margin-right:5px;
	float:left
}
#optionsframework .controls .of-background-position {
	width:125px;
	margin-right:5px;
	float:left
}
#optionsframework .controls .of-background-attachment {
	width:125px;
	margin-right:5px;
	float:left
}
#optionsframework .section-background .wp-picker-container {
	margin-bottom:10px;
}
#optionsframework .controls .of-radio-img-img {
	/*border:3px solid #f9f9f9;*/
	margin:0 5px 10px 0;
	display:none;
	cursor:pointer;
	float:left;
        padding: 3px;
        width: 60px;
        height: 60px;
}
#optionsframework .controls .of-radio-img-selected {
	border:3px solid #ccc
}
#optionsframework .controls .of-radio-img-img:hover {
	opacity:.8;
}
#optionsframework .controls .of-border-width {
	width:80px;
	float:left
}
#optionsframework .controls .of-border-style {
	width:120px;
	float:left
}
#optionsframework .hide {
	display:none;
}
#optionsframework .of-option-image {
	max-width:340px;
	margin:3px 0 18px 0;
}
#optionsframework .mini .controls select, #optionsframework .section .mini .controls {
	width: 140px;
}
#optionsframework .mini .controls input, #optionsframework .mini .controls {
	min-width:140px;
	width: 140px;
}
#optionsframework .mini .explain {
	max-width:74%;
}

/* Editor */

#optionsframework .section-editor .explain {
	max-width: 98%;
	float:none;
	margin-bottom:5px;
}

/* Image Uploader */

#optionsframework .controls input.upload {
	width:80%;
}
#optionsframework .screenshot {
	float:left;
	margin-left:1px;
	position:relative;
	width:344px;
	margin-top:3px;
}
#optionsframework .screenshot img {
	background:#fafafa;
	border-color:#ccc #eee #eee #ccc;
	border-style:solid;
	border-width:1px;
	float:left;
	max-width:334px;
	padding:4px;
	margin-bottom:10px;
}
#optionsframework .screenshot .remove-image {
	background:url("../images/ico-delete.png") no-repeat;
	border:medium none;
	bottom:4px;
	display:block;
	float:left;
	height:16px;
	padding:0;
	position:absolute;
	left:-4px;
	text-indent:-9999px;
	width:16px;
}
#optionsframework .screenshot .no_image .file_link {
	margin-left: 20px;
}
#optionsframework .screenshot .no_image .remove-button {
	bottom: 0px;
}
#optionsframework .reset-button {
	float:left;
	cursor:pointer;
}

/* Bottom Section */

#optionsframework-submit {
	padding: 7px 10px;
	border-top: 1px solid #ddd;
	background-color: #f1f1f1;
}
#optionsframework .button-primary {
	float:right;
}
#optionsframework .section:after {
	content: "";
	display: table;
}
#optionsframework .section:after {
	clear: both;
}