jQuery(function(){jQuery(function(){var a=jQuery("#search-toggle"),b=jQuery("#search-box");jQuery("#search-toggle").on("click",function(){"search-toggle"==jQuery(this).attr("id")&&(b.is(":visible")?a.removeClass("header-search-x").addClass("header-search"):a.removeClass("header-search").addClass("header-search-x"),b.slideToggle(300,function(){}))})}),function(){var b,c,a=jQuery(".main-navigation");if(a&&(b=a.find(".menu-toggle")))return c=a.find(".menu"),c&&c.children().length?void jQuery(".menu-toggle").on("click",function(){jQuery(this).toggleClass("on"),a.toggleClass("toggled-on")}):void b.hide()}(),jQuery(document).ready(function(){jQuery(".go-to-top").hide(),jQuery(window).scroll(function(){var a=jQuery(window).scrollTop();a>900?jQuery(".go-to-top").fadeIn():jQuery(".go-to-top").fadeOut()}),jQuery(".go-to-top").click(function(){return jQuery("html,header,body").animate({scrollTop:0},700),!1})});var a=jQuery("body");jQuery(document).on("wp-custom-header-video-loaded",function(){a.addClass("has-header-video")})});