
.icon-gplus:before { content: '\e800'; } /* '' */
.icon-stumbleupon:before { content: '\e801'; } /* '' */
.icon-pinterest:before { content: '\e802'; } /* '' */
.icon-digg:before { content: '\e803'; } /* '' */
.icon-spotify:before { content: '\e804'; } /* '' */
.icon-reddit:before { content: '\e805'; } /* '' */
.icon-dribbble:before { content: '\e806'; } /* '' */
.icon-flickr:before { content: '\e807'; } /* '' */
.icon-weibo:before { content: '\e808'; } /* '' */
.icon-linkedin:before { content: '\e809'; } /* '' */
.icon-vk:before { content: '\e80a'; } /* '' */
.icon-twitter:before { content: '\e80b'; } /* '' */
.icon-youtube:before { content: '\e80c'; } /* '' */
.icon-vimeo:before { content: '\e80d'; } /* '' */
.icon-xing:before { content: '\e80e'; } /* '' */
.icon-email:before { content: '\e80f'; } /* '' */
.icon-call:before { content: '\e810'; } /* '' */
.icon-facebook:before { content: '\e811'; } /* '' */
.icon-github-circled:before { content: '\e812'; } /* '' */
.icon-soundcloud:before { content: '\e813'; } /* '' */
.icon-tumblr:before { content: '\e814'; } /* '' */
.icon-cart:before { content: '\e815'; } /* '' */
.icon-instagram:before { content: '\e817'; } /* '' */
.icon-pencil:before { content: '\e819'; } /* '' */
.icon-user:before { content: '\e81b'; } /* '' */
.icon-search:before { content: '\e81c'; } /* '' */
.icon-menu:before { content: '\f0c9'; } /* '' */
.icon-foursquare:before { content: '\f180'; } /* '' */
.icon-trello:before { content: '\f181'; } /* '' */
.icon-behance:before { content: '\f1b4'; } /* '' */
.icon-birthday:before { content: '\f1fd'; } /* '' */
.icon-shopping-bag:before { content: '\f290'; } /* '' */