<?php
/**
 * The template for displaying the footer.
 *
 * Contains the closing of the #content div and all content after
 *
 * @package ares
 */
?><?php echo ares_close(); ?>
<?php wp_footer(); ?>
</body>
</html>