#mega_blog_sidebar_layout label{
    position: relative;
    display: inline-block;
    margin-right: 20px;
    margin-top: 10px;
}

#mega_blog_sidebar_layout label input{
    opacity: 0;
    position: absolute;
    left: 0;
    top: 0;
}

#mega_blog_sidebar_layout label img{
    vertical-align: middle;
    border: 2px solid transparent;
}
#mega_blog_sidebar_layout img:hover,
#mega_blog_sidebar_layout img:focus {
    border-color: #00a0d2;
}
#mega_blog_sidebar_layout label input:checked + img{
    border: 2px solid #00a0d2;
}