/*
Theme Name:Edge
Theme URI: https://themefreesia.com/themes/edge
Author: Theme Freesia
Author URI: https://themefreesia.com
Description: Edge is a Responsive Blogger WordPress Theme, Designed and Developed by Theme Freesia. Edge is Simple, clean, blog-focused, and designed for clarity. It is also translation ready and easily customizable with lots of options using Customizer. It consists contact us template, gallery template, widgets and sidebar. Get free support at https://tickets.themefreesia.com/ and View demo site at https://demo.themefreesia.com/edge.
Version: 1.2.1.5
Text Domain: edge
License: GNU General Public License version 3.0
License URI: http://www.gnu.org/licenses/gpl-3.0.html

Tags: threaded-comments, right-sidebar, custom-colors, four-columns, custom-background, custom-header, custom-menu, editor-style, sticky-post, theme-options, translation-ready, flexible-header, post-formats, custom-logo, footer-widgets, blog, e-commerce, news, photography, portfolio

All files, unless otherwise stated, are released under the GNU General Public License
version 3.0 (http://www.gnu.org/licenses/gpl-3.0.html)
==================================================
*/

/* 1.0 Browser Reset
================================================== */
html {
	overflow-y: scroll;
	-webkit-text-size-adjust: 100%;
	-ms-text-size-adjust: 100%;
	-webkit-font-smoothing: antialiased;
  	-moz-osx-font-smoothing: grayscale;
  	text-rendering: optimizelegibility;
}
html, body, div, span, applet, object, iframe,
h1, h2, h3, h4, h5, h6, p, blockquote, pre,
a, abbr, acronym, address, big, cite, code,
del, dfn, em, font, ins, kbd, q, s, samp,
small, strike, strong, sub, sup, tt, var,
dl, dt, dd, ol, ul, li,
fieldset, form, label, legend,
table, caption, tbody, tfoot, thead, tr, th, td {
	border: 0;
	font-family: inherit;
	font-size: 100%;
	font-style: inherit;
	font-weight: inherit;
	margin: 0;
	outline: 0;
	padding: 0;
	vertical-align: baseline;
}
*,
*:before,
*:after { /* box layout to all elements */
	-webkit-box-sizing: border-box;
	-moz-box-sizing:    border-box;
	box-sizing:         border-box;
}
body {
	background: #fff;
}
.fixed {
  position:fixed;
  top:0;
  left:0;
  width: 100%;
}
article,
aside,
details,
figcaption,
figure,
footer,
header,
main,
nav,
section {
	display: block;
}
ol, ul {
	list-style: none;
	margin: 0px;
}
ul li a,
ol li a {
	color: #545454;
}
ul li a:hover,
ol li a:hover {
	color: #C69f70;
}
ul ul,
ol ol,
ul ol,
ol ul {
	margin-bottom: 0;
}
table, th, td {
	border: 1px solid rgba(0, 0, 0, 0.1);
}
table {
	border-collapse: separate;
	border-spacing: 0px;
	border-width: 1px 0 0 1px;
	margin-bottom: 20px;
	width: 100%;
}
caption, th {
	font-weight: normal;
	text-align: left;
}
th {
	text-transform: uppercase;
	color: #333;
}
td, th {
	padding: 8px;
	border-width: 0 1px 1px 0;
}
a img {
	border: 0 none;
}
embed,
iframe,
object {
	max-width: 100%;
}
/* Internet Explorer 10 fix */
@-webkit-viewport {
	width: device-width;
}
@-moz-viewport {
	width: device-width;
}
@-ms-viewport {
	width: device-width;
}
@-o-viewport {
	width: device-width;
}
@viewport {
	width: device-width;
}
/* Other fixes*/
*,*:before,*:after {
	-webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    -ms-box-sizing: border-box;
    box-sizing: border-box;
}
/* Removes dotted line when focus */
:focus { 
	outline-color: transparent;
  	outline-style: none;
}
/* Webkit */
::selection {
	background: #C69f70;
	color: #fff;
}
/* Gecko/Mozilla */
::-moz-selection {
	background: #C69f70;
	color: #fff;
}

/* 2.0 Typography
================================================== */
body,
button,
input,
select,
textarea {
	color: #333;
	font: 400 14px/1.8 'Lato', sans-serif;
	word-wrap: break-word;
	overflow-x: hidden;
}

/* ----- #Headings  ----- */
h1, h2, h3, h4, h5, h6 {
	color: #333;
	font-family: 'Playfair Display', sans-serif;
	font-weight: 400;
	margin-top:0;
	padding-bottom: 20px;
}
h1 a, h2 a, h3 a, h4 a, h5 a, h6 a { 
	font-weight: inherit;
}
h1 {
	font-size: 30px;
	line-height: 37px;
}
h2 {
	font-size: 26px;
	line-height: 33px;
}
h3 {
	font-size: 24px;
	line-height: 31px;
}
h4 {
	font-size: 22px;
	line-height: 29px;
}
h5 {
	font-size: 20px;
	line-height: 27px;
}
h6 {
	font-size: 18px;
	line-height: 25px;
}

.highlight { 
	font-weight: 500;
}

/* ----- #Text Elements  ----- */
p {
	padding: 0;
	margin: 0 0 20px 0;
}

b, strong { font-weight: bold; }

dfn, cite, em, i {
	font-style: italic;
}

/* -----  #Blockquote shortcode start styles  ----- */
blockquote:before {
	color: rgba(0, 0, 0, 0.2);
	content: '\f10d';
	float: left;
	font-family: "FontAwesome";
	font-size: 30px;
	font-style: normal;
	line-height: 24px;
	padding-right: 10px;
}
blockquote {
	color: #333;
	font-family: 'Lato', sans-serif;
	font-size: 16px;
	font-style: italic;
		-webkit-hyphens: none;
		-moz-hyphens: none;
		-ms-hyphens: none;
	hyphens: none;
	letter-spacing: 0.5px;
	margin-bottom: 40px;
	padding: 20px 20px 0;
	position: relative;
	quotes: none;
	line-height: 28px;
}
blockquote cite {
	display: block;
	font-size: 15px;
	font-style: normal;
	text-align: right;
}
blockquote em,
blockquote i,
blockquote cite {
	font-style: normal;
}
address {
	display: block;
	margin: 0 0 1.6em;
}
pre:before {
	border: 1px solid rgba(255, 255, 255, 0.4);
	bottom: 3px;
	content: "";
	display: block;
	left: 3px;
	position: absolute;
	right: 3px;
	top: 3px;
}
pre {
	background-color: #333;
	clear: both;
	color: #ddd;
	font-family: "Courier 10 Pitch", Courier, monospace;
	font-size: 14px;
	line-height: 21px;
	margin-bottom: 20px;
	overflow: auto;
	padding: 30px;
	position: relative;
	white-space: pre;
}
code, kbd, tt, var {
	font: 14px Monaco, Consolas, "Andale Mono", "DejaVu Sans Mono", monospace;
	line-height: 21px;
}
abbr,
acronym,
dfn {
	border-bottom: 1px dotted #666;
	cursor: help;
}
mark, ins {
	background: #fff9c0;
	text-decoration: none;
	margin-bottom: 20px;
}
sup,
sub {
	font-size: 75%;
	height: 0;
	line-height: 1;
	position: relative;
	vertical-align: baseline;
}
sup {
	bottom: 1ex;
}
sub {
	top: .5ex;
}

.hidden {  display: none !important }

/* 3.0 Links
================================================== */
a {
	color: #C69f70;
	text-decoration: none;
	cursor:pointer;
}
a:focus,
a:active,
a:hover {
	text-decoration: none;
}

/* 4.0 Body Structure
================================================== */
#page {
	width: 100%;
	background-color: #fff;
}
.container {
	margin: 0 auto;
	max-width: 1170px;
	padding: 0;
	position: relative;
}
#primary .container {
	max-width: 100%;
}

/* --------------------------------------------
	Column
-------------------------------------------- */

.column {
	margin: 0 -20px;
}
.one-column,
.two-column,
.three-column,
.four-column {
	float: left;
	padding: 0 20px 40px;
}
.one-column,
#primary .two-column {
	width:100%;
}
.two-column,
.two-column-full-width,
#primary .three-column,
#primary .four-column-full-width,
#primary .four-column {
	width: 50%;
}
.three-column,
.boxed-layout-small .four-column-full-width,
.three-column-full-width {
	width: 33.33%;
}
.four-column,
.four-column-full-width {
	width: 25%;
}
#primary .three-column:nth-child(3n+4),
#primary .four-column:nth-child(4n+5) {
 	clear: none;
}
.two-column:nth-child(2n+3),
.three-column:nth-child(3n+4),
.four-column:nth-child(4n+5),
#primary .three-column:nth-child(2n+3),
#primary .four-column:nth-child(2n+3) {
 	clear: both;
}

/* 5.0 Buttons
================================================== */

/* ----- Default Button ----- */
.btn-default {
	border: 1px solid #666;
		-webkit-border-radius: 3px;
		-moz-border-radius: 3px;
	border-radius: 3px;
	color: #484848;
	display: inline-block;
	font-family: "Lato",sans-serif;
	font-weight: normal;
	line-height: 23px;
	margin: 10px 10px 0;
	padding: 7px 22px;
	text-align: center;
	text-transform: uppercase;
		-ms-transition: all 0.3s ease 0s;
		-moz-transition: all 0.3s ease 0s;
		-webkit-transition: all 0.3s ease 0s;
		-o-transition: all 0.3s ease 0s;
	transition: all 0.3s ease 0s;
}
.btn-default:hover {
	background-color: #C69f70;
	border: 1px solid #C69f70; 
	color: #fff;
}
.light {
	background-color: transparent;
	border-color: #fff;
    color: #fff;
}
.light-color {
	background-color: transparent;
	border-color: #fff;
    color: #fff;
}
.vivid {
	background-color: #C69f70;
	border: 1px solid #C69f70;
	color: #fff;
}
.light-color:hover,
.vivid:hover {
	background-color: #f4f4f4;
	border: 1px solid #f4f4f4;
	color: #484848;
}

/* ----- Go To Top Button ----- */
.go-to-top {
	position: fixed;
	bottom: 20px;
	right: 30px;
	z-index: 999;
}
.go-to-top a {
	border: 2px solid #C69f70;
	color: #C69f70;
	display: block;
	font-size: 26px;
	height: 38px;
	line-height: 32px;
	text-align: center;
		-ms-transition: all 0.3s ease-out;
		-moz-transition: all 0.3s ease-out;
		-webkit-transition: all 0.3s ease-out;
		-o-transition: all 0.3s ease-out;
	transition: all 0.3s ease-out;
	width: 38px;
}
.go-to-top a:hover {
	color: #fff;
	background-color: #C69f70;
}

/* ----- More Link Button ----- */
a.more-link {
	letter-spacing: 1px;
		-webkit-transition: all 300ms ease-in-out;
		-moz-transition: all 300ms ease-in-out;
		-o-transition: all 300ms ease-in-out;
		-ms-transition: all 300ms ease-in-out;	
	transition: all 300ms ease-in-out;
}
a.more-link:hover {
	letter-spacing: 2px;
}

/* 6.0 Accessibility
================================================== */
/* Text meant only for screen readers */
.screen-reader-text {
	clip: rect(1px, 1px, 1px, 1px);
	position: absolute !important;
	height: 1px;
	overflow: hidden;
	width: 1px;
}
.screen-reader-text:hover,
.screen-reader-text:active,
.screen-reader-text:focus {
	background-color: #f1f1f1;
		-webkit-border-radius: 3px;
		-moz-border-radius: 3px;
	border-radius: 3px;
		-webkit-box-shadow: 0 1px 2px rgba(0, 0, 0, 0.15);  /* Safari 3-4, iOS 4.0.2 - 4.2, Android 2.3+ */
		-moz-box-shadow:    0 1px 2px rgba(0, 0, 0, 0.15);  /* Firefox 3.5 - 3.6 */
	box-shadow:         	0 1px 2px rgba(0, 0, 0, 0.15);  /* Opera 10.5, IE 9, Firefox 4+, Chrome 6+, iOS 5 */
	clip: auto !important;
	color: #C69f70;
	display: block;
	font-size: 14px;
	font-weight: bold;
	height: auto;
	left: 5px;
	line-height: normal;
	padding: 15px 23px 14px;
	text-decoration: none;
	top: 5px;
	width: auto;
	z-index: 100000; /* Above WP toolbar */
}

/* 7.0 Alignments
================================================== */
.alignleft {
	display: inline;
	float: left;
	margin-right: 20px;
}
.alignright {
	display: inline;
	float: right;
	margin-left: 20px;
}
.aligncenter {
	clear: both;
	display: block;
	margin: 0 auto;
}

/* 8.0 Breadcrumb
================================================== */
.breadcrumb {
	float: right;
	font-size: 13px;
	margin-top: 6px;
}
.breadcrumb,
.breadcrumb a:hover {
	color: #999;
}
.breadcrumb a {
	color: #333;
}
.breadcrumb .home:before {
	content: '\f015';
	display: inline-block;
	font-family: "FontAwesome";
	font-size: 16px;
	font-style: normal;
	line-height: 21px;
	margin-right: 4px;
	vertical-align: top;
}

/* 9.0 Universal Clearfix
================================================== */
/* slightly enhanced, universal clearfix hack */
.clearfix:after {
     visibility: hidden;
     display: block;
     font-size: 0;
     content: " ";
     clear: both;
     height: 0;
     }
.clearfix { display: inline-block; }

/* start commented backslash hack \*/

* html .clearfix { height: 1%; }
.clearfix { display: block; }
/* close commented backslash hack */


/* 10.0 Forms
================================================== */
button,
input,
select,
textarea {
	font-size: 100%; /* Corrects font size in all browsers */
	margin: 0; /* Addresses margins set differently in IE6/7, F3/4, S5, Chrome */
	vertical-align: baseline; /* Appearance and consistency in all browsers */
	*vertical-align: middle; /* Appearance and consistency in IE6/IE7 */
}
input[type="text"],
input[type="email"],
input[type="url"],
input[type="tel"],
input[type="number"],
input[type="date"],
input[type="search"],
input[type="password"],
textarea {
	padding: 10px;
	border: 1px solid rgba(0, 0, 0, 0.1);
		-webkit-border-radius: 5px;
		-moz-border-radius: 5px;
	border-radius: 5px;
	width: 100%;
	margin-bottom: 30px;
	background-color: #fafafa;
}
input[type="reset"],
input[type="button"],
input[type="submit"] {
	background-color: #C69f70;
		-webkit-border-radius: 3px;
		-moz-border-radius: 3px;
	border-radius: 3px;
	border: 0 none;
	color: #fff;
	cursor: pointer;
	display: block;
	margin-bottom: 30px;
	padding: 6px 18px;
	text-align: center;
	text-transform: uppercase;
		-ms-transition: all 0.3s ease-out;
		-moz-transition: all 0.3s ease-out;
		-webkit-transition: all 0.3s ease-out;
		-o-transition: all 0.3s ease-out;
	transition: all 0.3s ease-out;
}
input[type="reset"]:hover,
input[type="button"]:hover,
input[type="submit"]:hover {
	background-color: #747474;
}
input[type="text"]:focus,
input[type="email"]:focus,
input[type="search"]:focus,
input[type="password"]:focus,
textarea:focus {
	border-color: rgba(0, 0, 0, 0.20);
	background-color: #fff;
}
input[type="checkbox"],
input[type="radio"] {
	padding: 0; /* Addresses excess padding in IE8/9 */
}

input[type=search] {
  -webkit-appearance: none;
}

/* #Search Form 
================================================== */
.header-search, .header-search-x {
	color: #000;
	cursor: pointer;
	display: block;
	font-family: "FontAwesome";
	font-size: 14px;
	font-style: normal;
	margin: 15px 10px 0;
	position: absolute;
	right: 0;
	top: 0;
}
.header-search:before {
	content: '\f002';
}
.header-search-x:before {
	content: '\f010';
}
.header-search:hover, .header-search-x:hover {
	color: #C69f70;
}

/** hidden search field **/
#search-box {
	background-color: rgba(255, 255, 255, 0.8);
		-webkit-box-shadow: 0 6px 8px -6px rgba(0, 0, 0, 0.15);
		-moz-box-shadow: 0 6px 8px -6px rgba(0, 0, 0, 0.15);
	box-shadow: 0 6px 8px -6px rgba(0, 0, 0, 0.15);
	display: none;
	padding: 15px;
	position: absolute;
	top: 60px;
	width: 100%;
	z-index: 9999;
}
#search-box input.search-field {
	width: calc(100% - 100px);
}
#search-box .search-submit {
	width: 100px;
}
#search-box input[type="search"] {
	background-color: transparent;
}

/* 11.0 Logo-Name-Slogan
================================================== */
#site-branding {
	margin: 0 auto;
	padding: 20px 0;
	text-align: center;
	width: 40%;
}
#site-logo {
	display: block;
	margin: 0 auto;
}
#site-title {
	font-size: 40px;
	font-weight: normal;
	line-height: 48px;
	padding: 0 0 20px;
	text-align: center;
}
#site-title a {
	color: #333;
	display: block;
}
#site-description {
	color: #333;
	font-family: 'Lato', sans-serif;
	font-size: 11px;
	font-weight: 700;
	letter-spacing: 0.4em;
	line-height: 19px;
	margin: 0;
	padding-bottom: 10px;
	text-align: center;
	text-transform: uppercase;
}
.nav-site-title {
	float: left;
	height: 0;
	opacity: 0;
		-moz-opacity: 0;
		filter:alpha(opacity=0);
	padding: 0;
}
.is-sticky .nav-site-title {
	height: auto;
	opacity: 1;
		-moz-opacity: 1;
		filter:alpha(opacity=100);
	padding: 10px 0;
		-moz-transition: all 500ms ease-in-out 0s;
		-o-transition: all 500ms ease-in-out 0s;
		-webkit-transition: all 500ms ease-in-out 0s;
	transition: all 500ms ease-in-out 0s;

}

/* Header Media */
.has-header-video .custom-header {
	position: relative;
}

.has-header-video .custom-header {
	display: table;
	height: 300px;
	height: 75vh;
	width: 100%;
}

.has-header-video .custom-header-media {
	bottom: 0;
	left: 0;
	overflow: hidden;
	position: absolute;
	right: 0;
	top: 0;
	width: 100%;
}

.has-header-video .custom-header-media video,
.has-header-video .custom-header-media iframe {
	position: fixed;
	height: auto;
	left: 50%;
	max-width: 1000%;
	min-height: 100%;
	min-width: 100%;
	min-width: 100vw; /* vw prevents 1px gap on left that 100% has */
	width: auto;
	top: 50%;
	padding-bottom: 1px; /* Prevent header from extending beyond the footer */
	-ms-transform: translateX(-50%) translateY(-50%);
	-moz-transform: translateX(-50%) translateY(-50%);
	-webkit-transform: translateX(-50%) translateY(-50%);
	transform: translateX(-50%) translateY(-50%);
}

.wp-custom-header .wp-custom-header-video-button { /* Specificity prevents .color-dark button overrides */
	background-color: rgba(34, 34, 34, 0.5);
	border: 1px solid rgba(255, 255, 255, 0.6);
	color: rgba(255, 255, 255, 0.6);
	cursor: pointer;
	font-size: 0;
	height: 45px;
	overflow: hidden;
	padding: 0;
	position: fixed;
	right: 30px;
	top: 30px;
	-webkit-transition: background-color 0.2s ease-in-out, border-color 0.2s ease-in-out, color 0.3s ease-in-out;
	transition: background-color 0.2s ease-in-out, border-color 0.2s ease-in-out, color 0.3s ease-in-out;
	width: 45px;
}

.wp-custom-header .wp-custom-header-video-button:hover,
.wp-custom-header .wp-custom-header-video-button:focus { /* Specificity prevents .color-dark button overrides */
	border-color: rgba(255, 255, 255, 0.8);
	background-color: rgba(34, 34, 34, 0.8);
	color: #fff;
}

.wp-custom-header .wp-custom-header-video-button.wp-custom-header-video-play:after,
.wp-custom-header .wp-custom-header-video-button.wp-custom-header-video-pause:after {
	color: #fff;
	font-family: "FontAwesome";
	font-size: 18px;
	font-style: normal;
	font-weight: normal;
	opacity: 0.7;
		-moz-opacity: 0.7;
		filter:alpha(opacity=70);
}

.wp-custom-header .wp-custom-header-video-button.wp-custom-header-video-play:after {
	content: "\f04c";
}
.wp-custom-header .wp-custom-header-video-button.wp-custom-header-video-pause:after{
	content: "\f04b";
}

.admin-bar .wp-custom-header-video-button {
	top: 62px;
}

/* For browsers that support 'object-fit' */
@supports ( object-fit: cover ) {
	.has-header-image .custom-header-media img,
	.has-header-video .custom-header-media video,
	.has-header-video .custom-header-media iframe,
	.has-header-image:not(.twentyseventeen-front-page):not(.home) .custom-header-media img {
		height: 100%;
		left: 0;
		-o-object-fit: cover;
		object-fit: cover;
		top: 0;
		-ms-transform: none;
		-moz-transform: none;
		-webkit-transform: none;
		transform: none;
		width: 100%;
	}
}
.has-header-video #sticky_header {
    background-color: #fff;
    position: relative;
}
.has-header-video .top-header .widget_contact ul li a {
	color: #fff;
}
.has-header-video .social-links a {
	color: #fff;
}
.has-header-video .main-slider {
	background-color: #fff;
    position: relative;
}
.has-header-video #content {
    background-color: #fff;
    position: relative;
}
.has-header-video #colophon {
    background-color: #fff;
    position: relative;
}
.has-header-video #site-title a,
.has-header-video #site-description {
    color: #fff;
}
.has-header-video .top-header:before {
    /* Permalink - use to edit and share this gradient: http://colorzilla.com/gradient-editor/#000000+0,000000+100&0+0,0.3+75 */
    background: -moz-linear-gradient(to top, rgba(0, 0, 0, 0) 0%, rgba(0, 0, 0, 0.5) 75%, rgba(0, 0, 0, 0.5) 100%); /* FF3.6-15 */
    background: -webkit-linear-gradient(to top, rgba(0, 0, 0, 0) 0%, rgba(0, 0, 0, 0.5) 75%, rgba(0, 0, 0, 0.5) 100%); /* Chrome10-25,Safari5.1-6 */
    background: linear-gradient(to bottom, rgba(0, 0, 0, 0) 0%, rgba(0, 0, 0, 0.5) 75%, rgba(0, 0, 0, 0.5) 100%); /* W3C, IE10+, FF16+, Chrome26+, Opera12+, Safari7+ */
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr="#00000000", endColorstr="#4d000000", GradientType=0); /* IE6-9 */
    bottom: 0;
    content: "";
    display: block;
    height: 100%;
    left: 0;
    position: absolute;
    right: 0;
    z-index: 0;
}
.has-header-video .top-header {
    position: relative;
    z-index: 1;
}

/* Hides div in Customizer preview when header images or videos change. */
body:not(.has-header-image):not(.has-header-video) .custom-header-media {
	display: none;
}

/* #Horizontal Line
================================================== */
hr {
	background-color: rgba(0, 0, 0, 0.1);
	border: 0;
	height: 1px;
	margin-bottom: 1.5em;
}

/* 12.0 Images
================================================== */
img {
	height: auto;/* Make sure images are scaled correctly. */
	max-width: 100%;/* Adhere to container width. */
	vertical-align: top;
}
img.alignleft,
img.alignright,
img.aligncenter {
	margin-top: 20px;
	margin-bottom: 20px;
}
figure {
	margin: 0;
}
img#wpstats {
	display: none;
}
.entry-content img,
.comment-content img,
.widget img {
	max-width: 100%;
}
.img-border {
	background-color: #fff;
	padding: 5px;
	border: 1px solid #ccc;
}

/* ----- Media ----- */
.page-content img.wp-smiley,
.entry-content img.wp-smiley,
.comment-content img.wp-smiley {
	border: none;
	margin-bottom: 0;
	margin-top: 0;
	padding: 0;
}
.wp-caption {
	margin-bottom: 20px;
	max-width: 100%;
}
.wp-caption a {
	display: block;
	position: relative;
}
.wp-caption .wp-caption-text {
	margin-bottom: 0;
	padding: 10px 0;
	border-bottom: 1px solid rgba(0, 0, 0, 0.1);
}
.wp-caption .wp-caption-text,
.gallery-caption {
	font-style: italic;
}

/* 13.0 Margin-Padding-Border Override Classes
================================================== */
.margin-top-none {
	/* Clear Margin Top */
	margin-top: 0px !important;
}
.margin-bottom-none {
	/* Clear Margin Bottom */
	margin-bottom: 0px !important;
}
.margin-right-none {
	/* Clear Margin Right */
	margin-right: 0px !important;
}
.margin-left-none {
	/* Clear Margin Left */
	margin-left: 0px !important;
}
.padding-top-none {
	/* Clear Padding Top */
	padding-top: 0px !important;
}
.padding-bottom-none {
	/* Clear Padding Bottom */
	padding-bottom: 0px !important;
}
.padding-right-none {
	/* Clear Padding Right */
	padding-right: 0px !important;
}
.padding-left-none {
	/* Clear Padding Left */
	padding-left: 0px !important;
}
.border-top-none {
	/* Clear Border Top */
	border-top: 0 none !important;
}
.border-bottom-none {
	/* Clear Border Bottom */
	border-bottom: 0 none !important;
}
.border-right-none {
	/* Clear Border Right */
	border-right: 0 none !important;
}
.border-left-none {
	/* Clear Border Left */
	border-left: 0 none !important;
}
.shadow-none {
	/* Remove Shadow */
	    -webkit-box-shadow: none !important;
	    -moz-box-shadow: none !important;
    box-shadow: none !important;
}
.margin-bottom-none p {
    /* Clear Inner p Tags Margin Bottom */
    margin-bottom: 0 !important;
}

/* 14.0 Layouts
================================================== */
/* ----- Photography Layout ----- */
.photography #content {
	padding: 0;
}

/*------ Boxed Layout ------*/
.boxed-layout #page {
	max-width: 1230px;
	margin: 0px auto;
		-webkit-box-shadow: 0 1px 6px rgba(0, 0, 0, 0.15);  /* Safari 3-4, iOS 4.0.2 - 4.2, Android 2.3+ */
		-moz-box-shadow:    0 1px 6px rgba(0, 0, 0, 0.15);  /* Firefox 3.5 - 3.6 */
	box-shadow:         	0 1px 6px rgba(0, 0, 0, 0.15);  /* Opera 10.5, IE 9, Firefox 4+, Chrome 6+, iOS 5 */
}
.boxed-layout #colophon,
.boxed-layout-small #colophon {
	margin-bottom: 30px;
}
.boxed-layout-small #page {
	max-width: 1038px;
	margin: 0px auto;
		-webkit-box-shadow: 0 1px 6px rgba(0, 0, 0, 0.15);  /* Safari 3-4, iOS 4.0.2 - 4.2, Android 2.3+ */
		-moz-box-shadow:    0 1px 6px rgba(0, 0, 0, 0.15);  /* Firefox 3.5 - 3.6 */
	box-shadow:         	0 1px 6px rgba(0, 0, 0, 0.15);  /* Opera 10.5, IE 9, Firefox 4+, Chrome 6+, iOS 5 */
	}
.boxed-layout-small .container {
	margin: 0px auto;
	max-width: 978px;
	padding: 0;
	position: relative;
}
.boxed-layout #page,
.boxed-layout-small #page {
	overflow: hidden;
}

/* ----- small_image_blog and single_column_blog ----- */
.small_image_blog #primary .post:not(:nth-child(1)),
.single_column_blog #primary .post:not(:nth-child(1)) {
	padding: 0;
	width: 100%;
}
.small_image_blog #primary .post.sticky:not(:nth-child(1)),
.single_column_blog #primary .post.sticky:not(:nth-child(1)) {
	padding: 30px 30px 40px;
	width: 100%;
}
.small_image_blog .entry-title {
	text-align: left;
}
.small_image_blog .entry-header .entry-meta {
	text-align: left;
}
.small_image_blog .post-featured-image {
	width: 40%;
	float: left;
	display: inline-block;
	margin-right: 20px;
	margin-bottom: 20px;
	overflow: hidden;
}

.search-results.small_image_blog #primary .page {
	display: block;
	float: left;
	margin-bottom: 60px;
}


/* 15.0 Header Section
================================================== */
/* ----- Top Header Bar ----- */
.top-header {
	color: #000;
	border-bottom: 1px solid rgba(0, 0, 0, 0.1);
	text-align: center;
}
.top-header .widget_contact {
	font-size: 13px;
	float: left;
	margin-bottom: 0;
	padding: 6px 0 7px;
	width: 30%;
}
.top-header .widget_contact ul li {
	float: left;
	margin-right: 15px;
	padding: 2px 0;
}
.top-header .widget_contact ul li a {
	color: #000;
}
.top-header .widget_contact ul li a:hover {
	color: #C69f70;
}
#sticky_header {
	background-color: #fff;
	border-bottom: 1px solid rgba(0, 0, 0, 0.1);
	width: 100%;
  	z-index: 999;
}
.is-sticky #sticky_header {
	background-color: rgba(255, 255, 255, 0.7);
		-webkit-box-shadow: 0 1px 2px rgba(0, 0, 0, 0.15);
		-moz-box-shadow: 0 1px 2px rgba(0, 0, 0, 0.15);
  	box-shadow: 0 1px 2px rgba(0, 0, 0, 0.15);
	border-bottom: none;
	  	-moz-transition: all 500ms ease-out 0s;
		-o-transition: all 500ms ease-out 0s;
		-webkit-transition: all 500ms ease-out 0s;
	transition: all 500ms ease-out 0s;
}

@media only screen and (max-width: 767px) {
	.is-sticky #sticky_header {
		background-color: #fff;
	}
}

/* ----- Header Widget Title ----- */
.top-header .widget-title {
	display: none;
}

/* ----- Header Image ----- */
.header-image {
	width: 100%;
	height: auto;
}


/* 16.0 Social Links
================================================== */
.header-social-block {
	float: right;
	width: 30%;
}
.social-links {
	margin-top: 0px;
	float: right;
}
.social-links a {
	color: #333;
	display: block;
	float: left;
	font-size: 14px;
	margin: 10px 0 0 5px;
	text-align: center;
	height: 30px;
	line-height: 27px;
	border-radius: 3px;
	width: 30px;
}
.social-links a[href*="facebook.com"]:hover {
	background-color: #3B5998;
	color: #FFF;
}
.social-links a[href*="twitter.com"]:hover {
	background-color: #33CCFF;
	color: #FFF;
}
.social-links a[href*="plus.google.com"]:hover {
	background-color: #DF4B38;
	color: #FFF;
}
.social-links a[href*="linkedin.com"]:hover {
	background-color: #007BB6;
	color: #FFF;
}
.social-links a[href*="instagram.com"]:hover {
	background-color: #8E6051;
	color: #FFF;
}
.social-links a[href*="flickr.com"]:hover {
	background-color: #0063DB;
	color: #FFF;
}
.social-links a[href*="pinterest.com"]:hover {
	background-color: #CB2027;
	color: #FFF;
}
.social-links a[href*="dribbble.com"]:hover {
	background-color: #F26798;
	color: #FFF;
}

/* 17.0 Navigation
================================================== */
.main-navigation {
	margin: 0 auto;
	padding: 0 30px 0 0;
	text-align: center;
}
.is-sticky .main-navigation .menu {
	float: right;
}
@media only screen and (max-width: 767px) {
	.is-sticky .main-navigation .menu {
		float: inherit;
	}
}
.main-navigation > ul > li {
	position: relative;
	display: inline-block;
}
.main-navigation a {
	color: #333;
	display: block;
	font-family: 'Lato', sans-serif;
	font-size: 12px;
	font-weight: bold;
	letter-spacing: 0.2em;
	padding: 15px;
	text-align: left;
	text-transform: uppercase;
}
.main-navigation a:hover,
.main-navigation ul li.current-menu-item a,
.main-navigation ul li.current_page_ancestor a,
.main-navigation ul li.current-menu-ancestor a,
.main-navigation ul li.current_page_item a,
.main-navigation ul li:hover > a,
.main-navigation li.current-menu-ancestor.menu-item-has-children > a:after,
.main-navigation li.current-menu-item.menu-item-has-children > a:after,
.main-navigation ul li:hover > a:after,
.main-navigation li.menu-item-has-children > a:hover:after,
.main-navigation li.page_item_has_children > a:hover:after {
	color: #C69f70;
}

/* ----- Dropdown ----- */
.main-navigation ul li ul,
.main-navigation ul li:hover ul ul,
.main-navigation ul ul li:hover ul ul,
.main-navigation ul ul ul li:hover ul ul,
.main-navigation ul ul ul ul li:hover ul ul {
	visibility:hidden;
}
.main-navigation ul li ul {
	list-style-type: none;
	position: absolute;
	top: 100px;
	padding: 0;
	margin: 0;
	opacity: 0;
		-moz-opacity: 0;
		filter:alpha(opacity=0);
	visibility:hidden;
	line-height: 32px;
	background-color: #fff;
		-webkit-box-shadow: 0 1px 6px rgba(0, 0, 0, 0.15);
		-moz-box-shadow:    0 1px 6px rgba(0, 0, 0, 0.15);
	box-shadow:         	0 1px 6px rgba(0, 0, 0, 0.15);
	width: 200px;
	z-index: 9999;
		-webkit-transition: 	all .50s ease;
		-moz-transition: 		all .50s ease;
		-ms-transition:		all .50s ease;
		-o-transition: 		all .50s ease;
	transition: 				all .50s ease;
}
.main-navigation > ul > li:hover > ul,
.main-navigation > ul > li.focus > ul {
	display: block;
	opacity: 1;
		-moz-opacity: 1;
		filter:alpha(opacity=100);	
  	visibility:visible;
  	top: 52px;
}
.main-navigation ul li ul li {
	float: none;
	margin: 0;
	position: relative;
	text-align: left;
	width: 200px;
	z-index: 1;
}
.main-navigation ul li ul li:before {
    border-top: 1px solid #eee;
    content: "";
    height: 1px;
    left: 10px;
    position: absolute;
    top: 0;
    width: 90%;
}
.main-navigation ul li ul li:first-child:before {
    border-top: none;
}
.main-navigation ul li ul li a,
.main-navigation ul li.current-menu-item ul li a,
.main-navigation ul li ul li.current-menu-item a,
.main-navigation ul li.current_page_ancestor ul li a,
.main-navigation ul li.current-menu-ancestor ul li a,
.main-navigation ul li.current_page_item ul li a {
	float: none;
	line-height: 20px;
	font-size: 14px;
	height: inherit;
	letter-spacing: 0.1em;
	padding: 12px 15px;
	color: #333;
	text-transform: capitalize;
}
.main-navigation ul li ul li a:hover,
.main-navigation ul li ul li:hover > a,
.main-navigation ul li.current-menu-item ul li a:hover {
	color: #C69f70;
}
.main-navigation ul li ul li ul {
	left: 190px;
	top: 50px;
}
.main-navigation ul li:last-child ul li ul {
	left: -200px;
}
.main-navigation ul ul li:hover ul,
.main-navigation ul ul li.focus ul,
.main-navigation ul ul ul li:hover ul,
.main-navigation ul ul ul li.focus ul {
	top: 0;
	display: block;
	opacity: 1;
		-moz-opacity: 1;
		filter:alpha(opacity=100);	
  	visibility:visible;
}
.main-navigation li.menu-item-has-children > a:after,
.main-navigation li li.menu-item-has-children > a:after,
.main-navigation li.page_item_has_children > a:after,
.main-navigation li li.page_item_has_children > a:after {
   font-family: 'FontAwesome';
   font-style: normal;
   font-weight: normal;
   text-decoration: inherit;
   color: #000;
   font-size: 14px;
   padding-left: 6px;
}
.main-navigation li.menu-item-has-children > a:after,
.main-navigation li.page_item_has_children > a:after {
   content: "\f107";
}
.main-navigation li li.menu-item-has-children > a:after,
.main-navigation li li.page_item_has_children > a:after {
   content: "\f105";
   position: absolute;
   right: 15px;
}

/* ----- Responsive Navigation ----- */
.menu-toggle {
	display: none;
}
.line-one,
.line-two,
.line-three {
	background-color: #333;
}

/* 18.0 Content
================================================== */
#content {
	padding: 70px 0 30px;
}
#main ul {
	list-style-type: disc;
}
#main ol {
	list-style-type: decimal;
}
#main ol ol {
	list-style: upper-alpha;
}
#main ol ol ol {
	list-style: lower-roman;
}
#main ol ol ol ol {
	list-style: lower-alpha;
}
#primary {
	float: left;
	width: 70%;
}

/* 19.0 Sidebars
================================================== */
#secondary {
	float: left;
	padding-left: 40px;
	width: 30%;
}

/* 20.0 Post
================================================== */
.entry-header {
	padding-bottom: 15px;
}
.post {
	margin-bottom: 50px;
}
.post:first-child .entry-content p:first-child:first-letter {
	border-right: 1px solid #222;
	display: block;
	float: left;
	font-family: 'Playfair Display', sans-serif;
	font-size: 80px;
	line-height: 80px;
	margin-bottom: 10px;
	margin-right: 22px;
	margin-top: 10px;
	padding: 10px 14px;
	text-align: center;
}
.post:first-child .entry-content blockquote p:first-child:first-letter {
	border-right: none;
	float: inherit;
	font-family: inherit;
	font-size: inherit;
	line-height: inherit;
	margin: inherit;
	padding: inherit;
}
#primary .post:not(:nth-child(1)) {
	width: 50%;
	float: left;
	padding: 0 0 0 15px;
}
#primary .post:nth-child(2n) {
	padding-right: 15px;
	padding-left: 0px;
}
#primary .post:nth-child(2n+2) {
	clear: both;
}
/* ----- Sticky Post ----- */
#main .sticky {
	background-color: #f4f4f4;
	padding: 30px 30px 40px;
	margin-bottom: 50px;
}
#primary .post.sticky:not(:nth-child(1)) {
	margin-left: 15px;
	padding: 20px 20px 30px;
	width: calc(50% - 15px);
}
#primary .post.sticky:nth-child(2n) {
	margin-right: 15px;
	margin-left: 0px;
}
.post-content {
 	background-color: #fff;
	position: relative;
}
/* ----- Entry Titles ----- */
.entry-title {
	font-size: 24px;
	line-height: 1.2;
	text-align: center;
	text-transform: none;

}
.entry-title,
.entry-title a {
	color: #333;
}
.entry-title a:hover,
.entry-title a:focus,
.entry-title a:active {
	color: #C69f70;
}

/* ----- Entry Meta ----- */
.entry-meta {
	overflow: hidden;
	text-align: center;
}
.entry-meta,
.entry-meta a {
	color: #999;
	font-size: 13px;
	line-height: 21px;
}
.entry-meta span:hover,
.entry-meta a:hover {
	color: #C69f70;
}
.single-post .entry-header .entry-meta,
.single-post .entry-footer {
	text-align: left;
}
.cat-links,
.cat-links a,
.tag-links,
.tag-links a {
	color: #C69f70;
	font-size: 11px;
	font-weight: 400;
	letter-spacing: 2px;
	text-transform: uppercase;
}
.cat-links a,
.tag-links a {
	padding-bottom: 15px;
	display: inline-block;
}
.cat-links,
.tag-links {
	margin-right: 15px;
	border-bottom: 1px solid #C69f70;
}
.entry-meta .entry-format,
.entry-meta .author,
.entry-meta .posted-on,
.entry-meta .comments,
.entry-meta .gallery {
	margin-right: 15px;
	margin-bottom: 5px;
}
.home .entry-meta .posted-on {
	margin-right: 0px;
}
.entry-meta .posted-on {
	font-style: italic;
}
.entry-meta .entry-format a {
	color: #C69f70;
}
.entry-format:before,
.entry-meta .entry-format:before,
.entry-header .entry-meta .entry-format:before {
	color: #C69f70;
	font-family: 'FontAwesome';
	font-size: 14px;
	line-height: 22px;
	display: inline-block;
	font-style: normal;
	font-weight: normal;
	font-variant: normal;
	speak: none;
	text-align: center;
	text-decoration: inherit;
	text-transform: none;
	vertical-align: top;
	margin-right: 5px;
	position: relative;
}

/* Entry-format */

.format-aside .entry-format:before {
	content: "\f06e";
}
.format-image .entry-format:before {
	content: "\f03e";
}
.format-gallery .entry-format:before {
	content: "\f1ad";
}
.format-video .entry-format:before {
	content: "\f03d";
}
.format-status .entry-format:before {
	content: "\f130";
}
.format-quote .entry-format:before {
	content: "\f10d";
}
.format-link .entry-format:before {
	content: "\f0c1";
}
.format-chat .entry-format:before {
	content: "\f086";
}
.format-audio .entry-format:before {
	content: "\f028";
}
.entry-footer {
	border-bottom: 1px solid rgba(0, 0, 0, 0.15);
	clear: both;
	text-align: center;
}
.entry-footer .entry-meta .entry-format,
.entry-footer .entry-meta .author {
	float: left;
}
.entry-footer .entry-meta .comments {
	float: right;
	margin-right: 0px;
}
/* ----- Entry Meta Link Button ----- */
.entry-footer a.more-link {
	border-bottom: 1px solid rgba(0, 0, 0, 0.15);
	border-top: 1px solid rgba(0, 0, 0, 0.15);
	display: inline-block;
	font-size: 11px;
	margin-bottom: 20px;
	padding: 3px 12px;
	text-transform: uppercase;
}

/* #Post Image
================================================== */
.post-image-content {
	position: relative;
}
.post-featured-image {
	margin-bottom: 30px;
	text-align: left;
}
.post-featured-image a {
	display: block;
} 
.home .post-featured-image {
	text-align: center;
}
.small_image_blog .post-featured-image {
	text-align: left;
}

/* #Entry Content
================================================== */
.entry-content {
	display: block;
	margin: 0px 0px 30px;
}
.entry-content dt,
.comment-content dt {
	font-weight: bold;
}
.entry-content dd,
.comment-content dd {
	margin-bottom: 20px;
}
.entry-content td,
.comment-content td {
	padding: 8px;
}
.entry-content ul,
.entry-content ol {
	margin: 0px 0px 30px 30px;
}
.entry-content li > ul, 
.entry-content li > ol {
	margin-bottom: 0px;
}

/* 21.0 Gallery
================================================== */
.gallery {
	display: inline-block;
	margin-bottom: 20px;
}
.gallery-item {
	float: left;
	margin: 0 4px 4px 0;
	overflow: hidden;
	position: relative;
}
.gallery-columns-1 .gallery-item {
	max-width: 100%;
}
.gallery-columns-2 .gallery-item {
	max-width: 48%;
	max-width: -webkit-calc(50% - 4px);
	max-width:         calc(50% - 4px);
}
.gallery-columns-3 .gallery-item {
	max-width: 32%;
	max-width: -webkit-calc(33.3% - 4px);
	max-width:         calc(33.3% - 4px);
}
.gallery-columns-4 .gallery-item {
	max-width: 23%;
	max-width: -webkit-calc(25% - 4px);
	max-width:         calc(25% - 4px);
}
.gallery-columns-5 .gallery-item {
	max-width: 19%;
	max-width: -webkit-calc(20% - 4px);
	max-width:         calc(20% - 4px);
}
.gallery-columns-6 .gallery-item {
	max-width: 15%;
	max-width: -webkit-calc(16.7% - 4px);
	max-width:         calc(16.7% - 4px);
}
.gallery-columns-7 .gallery-item {
	max-width: 13%;
	max-width: -webkit-calc(14.28% - 4px);
	max-width:         calc(14.28% - 4px);
}
.gallery-columns-8 .gallery-item {
	max-width: 11%;
	max-width: -webkit-calc(12.5% - 4px);
	max-width:         calc(12.5% - 4px);
}
.gallery-columns-9 .gallery-item {
	max-width: 9%;
	max-width: -webkit-calc(11.1% - 4px);
	max-width:         calc(11.1% - 4px);
}
.gallery-columns-1 .gallery-item:nth-of-type(1n),
.gallery-columns-2 .gallery-item:nth-of-type(2n),
.gallery-columns-3 .gallery-item:nth-of-type(3n),
.gallery-columns-4 .gallery-item:nth-of-type(4n),
.gallery-columns-5 .gallery-item:nth-of-type(5n),
.gallery-columns-6 .gallery-item:nth-of-type(6n),
.gallery-columns-7 .gallery-item:nth-of-type(7n),
.gallery-columns-8 .gallery-item:nth-of-type(8n),
.gallery-columns-9 .gallery-item:nth-of-type(9n) {
	margin-right: 0;
}
.gallery-columns-1.gallery-size-medium figure.gallery-item:nth-of-type(1n+1),
.gallery-columns-1.gallery-size-thumbnail figure.gallery-item:nth-of-type(1n+1),
.gallery-columns-2.gallery-size-thumbnail figure.gallery-item:nth-of-type(2n+1),
.gallery-columns-3.gallery-size-thumbnail figure.gallery-item:nth-of-type(3n+1) {
	clear: left;
}

/* #Post-Image-Paging Navigation
================================================== */
.wp-pagenavi,
#main ul.default-wp-page {
	margin: 50px 0;
}
.wp-pagenavi .pages {
	padding: 6px 12px;
	color: #747474;
}
.wp-pagenavi .current,
.wp-pagenavi a {
		-webkit-border-radius: 3px;
		-moz-border-radius: 3px;
	border-radius: 3px;
	color: #747474;
	display: block;
	float: left;
	border: 1px solid rgba(0, 0, 0, 0.15);
	padding: 4px 11px;
}
.wp-pagenavi .current,
.wp-pagenavi a:hover,
.wp-pagenavi span.current {
	color: #747474;
	border: 1px solid rgba(0, 0, 0, 0.15);
	background-color: #f4f4f4;
}
.wp-pagenavi span.current {
	font-weight: 200;
}
/* ----- wp-pagenavi ----- */
.wp-pagenavi {
	text-align: center;
}
.wp-pagenavi .current,
.wp-pagenavi a {
	display: inline-block;
	float: none;
	margin-left: 4px;
}

/* ----- Default wp-page ----- */
#main ul.default-wp-page {
	margin-left: 0;
	list-style: none;
	padding-bottom: 0;
}
ul.default-wp-page li a {
	color: #C69f70;
}
ul.default-wp-page li a:hover {
	color: #747474;
}
ul.default-wp-page li {
	padding: 0px 0px 20px;
}
ul.default-wp-page li.previous {
	float:left;	
}
ul.default-wp-page li.next {
	float:right;
}
ul.default-wp-page li a {
	display: inline-block;
}

/* 22.0 Attachments
================================================== */
.image-attachment div.attachment {
	background-color: #f9f9f9;
	border: 1px solid #ddd;
	border-width: 1px 0;
	margin: 0 -8.9% 1.625em;
	overflow: hidden;
	padding: 1.625em 1.625em 0;
	text-align: center;
}
.image-attachment div.attachment img {
	display: block;
	height: auto;
	margin: 0 auto 1.625em;
	max-width: 100%;
}
.image-attachment div.attachment a img {
	border-color: #f9f9f9;
}
.image-attachment div.attachment a:focus img,
.image-attachment div.attachment a:hover img,
.image-attachment div.attachment a:active img {
	border-color: #ddd;
	background-color: #fff;
}
.image-attachment .entry-caption p {
	font-size: 10px;
	letter-spacing: 0.1em;
	line-height: 2.6em;
	margin: 0 0 2.6em;
	text-transform: uppercase;
}

/* 23.0 Comments
================================================== */
.comments-title {
	font-size: 30px;
	font-weight: normal;
	line-height: 38px;
	padding-bottom: 15px;
}
#main .comments-area ul,
#main .comments-area ol {
	margin: 0 0 30px 30px;
}
#main .comments-area ul ul,
#main .comments-area ol ol {
	margin-bottom: 0;
}
.comments-area article {
	margin: 24px 0;
	margin: 1.714285714rem 0;
}
.comments-area article header {
	margin: 0 0 48px;
	margin: 0 0 3.428571429rem;
	overflow: hidden;
	position: relative;
}
.comments-area article header img {
	float: left;
	padding: 0;
	line-height: 0;
}
.comments-area article header cite,
.comments-area article header time {
	display: block;
	margin-left: 85px;
	margin-left: 6.071428571rem;
}
.comments-area article header cite {
	font-style: normal;
	font-size: 15px;
	font-size: 1.071428571rem;
	line-height: 1.42857143;
}
.comments-area article header time {
	line-height: 1.714285714;
	text-decoration: none;
	font-size: 12px;
	font-size: 0.857142857rem;
	color: #484848;
}
.comments-area article header a {
	text-decoration: none;
	color: #484848;
}
.comments-area article header a:hover {
	color: #21759b;
}
.comments-area article header cite a {
	color: #444;
}
.comments-area article header cite a:hover {
	text-decoration: underline;
}
.comments-area article header h4 {
	position: absolute;
	top: 0;
	right: 0;
	padding: 6px 12px;
	padding: 0.428571429rem 0.857142857rem;
	font-size: 12px;
	font-size: 0.857142857rem;
	font-weight: normal;
	color: #fff;
	background-repeat: repeat-x;
	background: #0088d0;
	background: -webkit-linear-gradient(#009cee, #0088d0);
	background: -moz-linear-gradient(#009cee, #0088d0);
	background: -ms-linear-gradient(#009cee, #0088d0);
	background: -o-linear-gradient(#009cee, #0088d0);
	background: -webkit-gradient(#009cee, #0088d0);
	background: linear-gradient(#009cee, #0088d0);
		-webkit-border-radius: 3px;
		-moz-border-radius: 3px;
	border-radius: 3px;
	border: 1px solid #007cbd;
}
.comments-area li.bypostauthor cite span {
	position: absolute;
	margin-left: 5px;
	margin-left: 0.357142857rem;
	padding: 2px 5px;
	padding: 0.142857143rem 0.357142857rem;
	font-size: 10px;
	font-size: 0.714285714rem;
}
a.comment-reply-link {
	font-size: 13px;
	font-size: 0.928571429rem;
	line-height: 1.846153846;
	color: #747474;
}
a.comment-reply-link:hover {
	color: #21759b;
}
.commentlist .pingback {
	line-height: 1.714285714;
	margin-bottom: 24px;
	margin-bottom: 1.714285714rem;
}
.commentlist .children {
	margin-left: 48px;
	margin-left: 3.428571429rem;
}

/* ----- Comment form ----- */
#respond {
	margin-top: 48px;
	margin-top: 3.428571429rem;
}
#respond h3#reply-title {
	font-size: 30px;
	font-weight: normal;
	line-height: 38px;
	padding-bottom: 15px;
}
#respond h3#reply-title #cancel-comment-reply-link {
	margin-left: 10px;
	margin-left: 0.714285714rem;
	font-weight: normal;
	font-size: 12px;
	font-size: 0.857142857rem;
}
#respond form {
	margin: 24px 0;
	margin: 1.714285714rem 0;
}
#respond form p {
	margin: 11px 0;
	margin: 0.785714286rem 0;
}
#respond form p.logged-in-as {
	margin-bottom: 24px;
	margin-bottom: 1.714285714rem;
}
#respond form label {
	display: block;
	line-height: 1.714285714;
}
#respond form input[type="text"],
#respond form textarea {
		-webkit-box-sizing: border-box;
  		-moz-box-sizing: border-box;
  	box-sizing: border-box;
	font-size: 12px;
	font-size: 0.857142857rem;
	line-height: 1.714285714;
	padding: 10px;
	padding: 0.714285714rem;
	width: 100%;
}
#respond form p.form-allowed-tags {
	margin: 0;
	font-size: 12px;
	font-size: 0.857142857rem;
	line-height: 2;
	color: #484848;
}
.required {
	color: red;
}
label ~ span.required {
	display: block;
	float: left;
	margin: -18px 0 0 -16px;
	margin: -1.285714286rem 0 0 -1.142857143rem;
}

/* 24.0 Pages
================================================== */
/* ----- Page Title ----- */
.page-header {
	padding: 0 0 30px;
	position: relative;
	overflow: hidden;
}
.error-404 .page-header {
	padding: 15px 20px 50px;
	margin-top: 0px;
	background-color: #fddbdd;
}
.error-404 .page-title {
	padding: 0px;
}
.error-404 .page-content {
	padding: 20px 0px;
}
.page-title {
	color: #333;
	float: left;
	font-size: 24px;
	line-height: 32px;
	padding: 0;
}

/* ----- Contact Page ----- */
.wpcf7-select {
	background-color: #fafafa;
	border: 1px solid rgba(0, 0, 0, 0.1);
	margin: 0 0 30px;
	padding: 10px;
	width: 40%;
	display: block;
}
.wpcf7 p {
	margin-bottom: 0;
}
input[type="file"]  {
	margin: 0 0 30px;
	display: block;
}
input[type="checkbox"] {
	margin: 0px 0px 30px;
}

/* 25.0 Widgets
================================================== */
.widget {
	margin-bottom: 30px;
}
.widget ul li a {
	color: #545454;
}
.widget ul li a:hover {
	color: #C69f70;
}
.widget-title {
	font-size: 16px;
	line-height: 24px;
	font-weight: 400;
	padding-bottom: 20px;
}
.widget-title,
.widget-title a {
	color:#333;
}
.widget-title a:hover {
	color: #C69f70;
}
#secondary .widget-title:after {
	-moz-border-bottom-colors: none;
	-moz-border-left-colors: none;
	-moz-border-right-colors: none;
	-moz-border-top-colors: none;
	border-color: #161616 transparent transparent;
	border-image: none;
	border-style: solid;
	border-width: 7px;
	content: "";
	height: 0;
	left: 50%;
	margin-left: -7px;
	position: absolute;
	top: 100%;
	width: 0;
}
#secondary .widget-title {
	background-color: #161616;
	color: #fff;
	font-size: 15px;
	line-height: 24px;
	letter-spacing: 1px;
	margin-bottom: 25px;
	padding: 8px 0;
	position: relative;
	text-align: center;
	text-transform: uppercase;
}

/* Search Widget
================================================== */
input.search-field {
		-webkit-border-radius: 0;
		-moz-border-radius: 0;
	border-radius: 0;
	color: #747474;
	float: left;
	font-size: 14px;
	height: 46px;
	line-height: 22px;
	margin: 0;
	outline: medium none;
	padding: 6px 8px;
	width: 80%; /* fallback if needed */
	width: calc(100% - 60px);
}
.search-submit {
	background-color: #C69f70;
	border: 1px solid #C69f70;
		-webkit-border-radius: 0;
		-moz-border-radius: 0;
	border-radius: 0;
	color: #fff;
	cursor: pointer;
	font-size: 16px;
	height: 46px;
	margin-left: -1px;
	outline: medium none;
	right: 0;
	width: 60px;
		-moz-transition: all 300ms ease-out 0s;
		-o-transition: all 300ms ease-out 0s;
		-webkit-transition: all 300ms ease-out 0s;
	transition: all 300ms ease-out 0s;
}
.search-submit:hover {
	font-size: 22px;
}

/* Promonational Area
================================================== */
.promonational-area {
	margin-bottom: 20px;
}
.promonational-img {
	background-position: center center;
	background-repeat: no-repeat;
	background-size: cover;
	height: 220px;
	padding: 15px;
	position: relative;
	width: 100%;
}
.promonational-area .promonational-link {
	bottom: 0;
	display: block;
	left: 0;
	position: absolute;
	right: 0;
	top: 0;
	z-index: 99;
}
.promonational-overlay {
	border: 1px solid #fff;
	height: 100%;
	position: relative;
	text-align: center;
}
.promonational-overlay h4 {
	background-color: rgba(255, 255, 255, 0.9);
	color: #000;
	display: inline-block;
	font-size: 11px;
	left: 50%;
	letter-spacing: 2px;
	line-height: 18px;
	max-width: 80%;
	padding: 8px 12px 7px 14px;
	position: absolute;
	text-transform: uppercase;
	top: 50%;
		-webkit-transform: translateY(-50%) translateX(-50%);
		-moz-transform: translateY(-50%) translateX(-50%);
		-o-transform: translateY(-50%) translateX(-50%);
		-ms-transform: translateY(-50%) translateX(-50%);
	transform: translateY(-50%) translateX(-50%);
}

/* Contact Widget
================================================== */
.widget_contact ul li i {
	font-size: 14px;
	line-height: 24px;
	padding-right: 5px;
	vertical-align: top;
}
.widget_contact ul li {
	padding: 6px 0 7px 0;
}
.widget_contact ul li a:hover {
	color: #C69f70;
}

/* Calendar Widget
================================================== */
.widget_calendar #wp-calendar {
	width: 90%;
	margin: 0 auto;
}
.widget_calendar #wp-calendar caption,
.widget_calendar #wp-calendar th,
.widget_calendar #wp-calendar td {
	text-align: center;
}
.widget_calendar #wp-calendar caption {
	font-size: 18px;
	padding: 0 0 30px;
	text-transform: uppercase;
}
.widget_calendar #wp-calendar th,
.widget_calendar #wp-calendar tfoot td {
	background-color: #f4f4f4;
}


/* Posts Widget
================================================== */
.widget_posts {
	margin-bottom: 30px;
}
.widget_posts .post-title a:hover {
	text-decoration: underline;
}
.widget_posts .article-calendar {
	font-size: 14px;
}

/* Tag Cloud Widget
================================================== */
.widget_tag_cloud a {
	border: 1px solid #ddd;
	color: #747474;
	display: inline-block;
	font-size: 13px !important;
	margin-bottom: 10px;
	margin-right: 5px;
	padding: 2px 12px;
}
.widget_tag_cloud a:hover {
	background-color: #eee;
}

/* ----- Site Info ----- */
.site-info {
	padding: 20px 0px 15px;
	background-color: #f8f8f8;
	font-size: 14px;
	line-height: 22px;
	text-align: center;
	background-position: center center;
	background-size: cover;
}
.site-info .social-links {
	float: none;
	margin-bottom: 15px;
	text-align: center;
}
.site-info .social-links {
	display: inline-block;
}
.site-info .social-links a {
	border: 1px solid #545454;
	color: #545454;
	display: inline-block;
	margin: 10px 8px 0;
}
.site-info .social-links a:hover {
	border-color: transparent;
}
.site-info .copyright {
	color: #848484;
	font-size: 13px;
	line-height: 21px;
	padding-top: 15px;
	text-align: center;
}
.site-info .copyright a {
	color: #999;
}
.site-info .copyright a:hover {
	color: #C69f70;
}

/* Googlemap Widget
================================================== */
.googlemaps_widget {
	width: 100%;
	margin-bottom: 50px;
}
.maps-container {
	border: 1px solid #ccc;
	margin: 0px;
	padding: 0px;
	height: 402px;
}
.googlemaps_widget iframe {
	width: 100%;
	height: 400px;
}

/* 26.0 Footer
================================================== */
#colophon p {
	margin-bottom: 15px;
}
#colophon {
	font-size: 13px;
	line-height: 21px;
}
#colophon .widget-wrap {
	background-color: #fff;
	border-bottom: 1px solid rgba(0, 0, 0, 0.1);
	border-top: 1px solid rgba(0, 0, 0, 0.1);
	color: #333;
}
#colophon .widget-area {
	margin: 0 -30px;
	padding: 50px 0 10px;
		display: -webkit-box;      /* OLD - iOS 6-, Safari 3.1-6 */
		display: -moz-box;         /* OLD - Firefox 19- (buggy but mostly works) */
		display: -ms-flexbox;      /* TWEENER - IE 10 */
		display: -webkit-flex;     /* NEW - Chrome */
	display: flex;             /* NEW, Spec - Opera 12.1, Firefox 20+ */
	    -webkit-box-orient: horizontal;
	    -moz-box-orient: horizontal;
	    -webkit-box-direction: normal;
	    -moz-box-direction: normal;
	    -ms-flex-direction: row;
	    -webkit-flex-direction: row;
    flex-direction: row;
}

#colophon .widget {
	margin-bottom: 30px;
}
#colophon .widget ul li a {
	color: #333;
}
#colophon .widget ul li a:hover {
	color: #C69f70;
}
#colophon .widget_categories ul li a,
#colophon .widget_pages ul li a,
#colophon .widget_nav_menu ul li a,
#colophon .widget_recent_entries ul li a,
#colophon .widget_categories ul li a,
#colophon .widget_recent_comments ul li a,
#colophon .widget_meta ul li a,
#colophon .widget_rss ul li a {
	display: block;
}
#colophon .widget_categories ul ul li a,
#colophon .widget_pages ul ul li a,
#colophon .widget_nav_menu ul ul li a,
#colophon .widget_recent_entries ul ul li a,
#colophon .widget_categories ul ul li a,
#colophon .widget_recent_comments ul ul li a,
#colophon .widget_meta ul ul li a,
#colophon .widget_rss ul ul li a {
	padding-left: 20px;
}
#colophon .widget_categories ul ul ul li a,
#colophon .widget_pages ul ul ul li a,
#colophon .widget_nav_menu ul ul ul li a,
#colophon .widget_recent_entries ul ul ul li a,
#colophon .widget_categories ul ul ul li a,
#colophon .widget_recent_comments ul ul ul li a,
#colophon .widget_meta ul ul ul li a,
#colophon .widget_rss ul ul ul li a {
	padding-left: 30px;
}
#colophon .widget-title:after {
	background-color: #C69f70;
	content: " ";
	display: block;
	height: 1px;
	margin: 12px 0 auto;
	width: 60px;
}
#colophon .widget-title {
	font-family: 'Lato', sans-serif;
	font-size: 18px;
	line-height: 26px;
	text-transform: uppercase;
}
.widget_search .widget-title {
	display: none;
}
.widget_rss ul li {
	display: block;
	padding: 10px 0px;
}
.widget_meta ul li,
.widget_recent_comments ul li,
.widget_categories ul li,
.widget_recent_entries ul li,
.widget_archive ul li {
	display: block;
	padding: 6px 0 7px 5px;
}
.widget_recent_entries span {
	display: block;
}
#colophon .widget_posts .post-title {
	font-size: 15px;
	line-height: 22px;
	padding-bottom: 0px;
}

/* Footer column
================================================== */
.column-4 {
	float: left;
	padding: 0 20px 40px;
}
.column-4 {
	width: 25%;
}
.column-4:nth-child(4n+5) {
 	clear: both;
}
#colophon .column-4 {
	margin-bottom: 30px;
	padding: 0 30px;
	border-right: 1px solid #e4e4e4;
		display: -webkit-box;      /* OLD - iOS 6-, Safari 3.1-6 */
		display: -moz-box;         /* OLD - Firefox 19- (buggy but mostly works) */
		display: -ms-flexbox;      /* TWEENER - IE 10 */
		display: -webkit-flex;     /* NEW - Chrome */
	display: flex;             /* NEW, Spec - Opera 12.1, Firefox 20+ */
		-webkit-box-orient: vertical;
	    -moz-box-orient: vertical;
	    -webkit-box-direction: normal;
	    -moz-box-direction: normal;
	    -ms-flex-direction: column;
	    -webkit-flex-direction: column;
    flex-direction: column;
}
#colophon .column-4:last-child {
	border-right: none;
}
/* ----- Footer Navigation ----- */
#footer-navigation {
	border-bottom: 1px solid rgba(0, 0, 0, 0.1);
	padding: 10px 0;
	text-align: center;
}
#footer-navigation a:hover{
    color: #C69f70;
}
#footer-navigation a {
    color: #333;
    display: block;
    float: left;
    font-size: 12px;
    font-weight: normal;
    padding: 0 20px;
    text-transform: uppercase;
}
#footer-navigation ul li {
	position: relative;
	display: inline-block;
}
#footer-navigation ul li:before {
	content: '';
    border-right: 1px solid #999;
    position: absolute;
    height: 40%;
    right: 0;
    top: 30%;
}
#footer-navigation ul li:last-child:before {
	border-right: none;
}

/* #Main Slider
================================================== */
.main-slider,
.main-slider .layer-slider,
.main-slider .container {
	position: relative;
	height: 100%;
}
.main-slider .show-display {
	display: block;
}
.main-slider .hide-display {
	display: none;
}
.main-slider .image-slider {
	background-position: center center;
	background-size: cover;
	  	-webkit-box-sizing: border-box;
  		-moz-box-sizing: border-box;
  	box-sizing: border-box;
  	min-height: 600px;
  	position: relative;
}
.slider-content {
	left: 0;
	position: absolute;
	right: 0;
	text-align: center;
	top: 50%;
		-webkit-transform: translateY(-50%);
		-moz-transform: translateY(-50%);
		-o-transform: translateY(-50%);
		-ms-transform: translateY(-50%);
	transform: translateY(-50%);
	margin: 0 auto;
	width: 70%;
}
.slider-content .slider-title,
.slider-content .slider-title a {
	color: #000;
	font-size: 36px;
	font-weight: 400;
	line-height: 44px;
}
.slider-content .slider-text h3 {
	color: #000;
	font-size: 16px;
	font-weight: 300;
	line-height: 24px;
}

/* ----- Slider Buttons ----- */
a.slider-prev, a.slider-next {
	color: #999;
	font-size: 80px;
	line-height: 1;
	opacity: 0;
		-moz-opacity: 0.3;
		filter:alpha(opacity=30);
	position: absolute;
	top: 50%;
		-webkit-transform: translateY(-50%);
		-moz-transform: translateY(-50%);
		-o-transform: translateY(-50%);
		-ms-transform: translateY(-50%);
	transform: translateY(-50%);
		-webkit-transition: all 300ms ease-out;
		-moz-transition: all 300ms ease-out;
		-o-transition: all 300ms ease-out;
		-ms-transition: all 300ms ease-out;	
	transition: all 300ms ease-out;
	z-index: 99;
}
a.slider-prev {
	left: 120px;
}
a.slider-next {
	right: 120px;
}
.main-slider:hover a.slider-prev {
	left: 70px;
	opacity: 0.3;
		-moz-opacity: 0.3;
		filter:alpha(opacity=30);
}
.main-slider:hover a.slider-next {
	right: 70px;
	opacity: 0.3;
		-moz-opacity: 0.3;
		filter:alpha(opacity=30);
}
.main-slider a.slider-prev:hover, .main-slider a.slider-next:hover {
    opacity: 0.7;
		-moz-opacity: 0.7;
		filter:alpha(opacity=70);
}

/* ----- Slider Pagination Buttons ----- */
.slider-button {
	text-align: center;
	line-height: 0;
	position: absolute;
	width: 100%;
	bottom: 40px;
	z-index: 99;
}
.slider-button a {
	background-color: transparent;
	border: 1px solid #999;
	cursor: pointer;
	display: inline-block;
	font-size: 0;
	height: 14px;
	line-height: 14px;
	margin: 0 3px;
	opacity: 0.5;
		-moz-opacity: 0.5;
		filter:alpha(opacity=50);
	text-align: center;
	vertical-align: middle;
	width: 14px;
}
nav.slider-button a.active, 
nav.slider-button a:hover {
	background-color: #ddd;
	  	-moz-transition:background .3s ease;
	  	-webkit-transition:background .3s ease;
	  	-ms-transition:background .3s ease;
  	transition:background .3s ease;
}

/* #bbpress
================================================== */
#bbpress-forums,
div.bbp-breadcrumb, div.bbp-topic-tags,
div.bbp-template-notice p,
#bbpress-forums .bbp-topic-content ul.bbp-topic-revision-log, 
#bbpress-forums .bbp-reply-content ul.bbp-topic-revision-log, 
#bbpress-forums .bbp-reply-content ul.bbp-reply-revision-log {
	font-size: 14px;
}
#bbpress-forums p.bbp-topic-meta img.avatar, 
#bbpress-forums ul.bbp-reply-revision-log img.avatar, 
#bbpress-forums ul.bbp-topic-revision-log img.avatar, 
#bbpress-forums div.bbp-template-notice img.avatar, 
#bbpress-forums .widget_display_topics img.avatar, 
#bbpress-forums .widget_display_replies img.avatar, 
#bbpress-forums p.bbp-topic-meta img.avatar {
	border: 0px;
	float: none;
	margin-bottom: 2px;
	margin-right: 1px;
}
.bbp-pagination {
	text-align: right;
}
.bbp-pagination-count {
	float: none;
}
#bbpress-forums ul.bbp-lead-topic,
#bbpress-forums ul.bbp-topics,
#bbpress-forums ul.bbp-forums,
#bbpress-forums ul.bbp-replies,
#bbpress-forums ul.bbp-search-results {
	font-size: 14px;
	overflow: hidden;
	border: 1px solid #ddd;
	margin-bottom: 20px;
	clear: both;
}
#bbpress-forums li.bbp-header,
#bbpress-forums li.bbp-footer {
	background: #f4f4f4;
	border: none;
	font-weight: bold;
	text-align: center;
	padding: 15px 18px 15px 18px;
}
#bbpress-forums li.bbp-footer {
	padding: 8px;
	border-top: 1px solid #ddd;
}
#bbpress-forums .bbp-topics a {
	color: #333;
}
#bbpress-forums .bbp-topics a:hover {
	color: #C69f70;
}
#bbpress-forums li.bbp-body ul.forum, 
#bbpress-forums li.bbp-body ul.topic {
	border-top: 1px solid #ddd;
}
#bbpress-forums li.bbp-header ul {
	font-size: 16px;
}
#bbpress-forums li.bbp-body ul.forum, #bbpress-forums li.bbp-body ul.topic {
	font-size: 14px;
	padding: 12px 0 10px 18px;	
}
#bbpress-forums .bbp-forum-info .bbp-forum-content,
#bbpress-forums p.bbp-topic-meta {
	font-size: 14px;
	margin: 5px 0 5px;
	padding: 0;
	word-wrap: break-word;
}
div.bbp-template-notice.info {
	color: #1891a8;
}
div.bbp-template-notice.info a {
	color: #1891a8;
	font-weight: 400;
}
#bbpress-forums p.bbp-topic-meta img.avatar {
  width:25px;
  height:25px;
}
#bbpress-forums fieldset.bbp-form {
	border: none;
	padding: 0;
}
#bbpress-forums fieldset.bbp-form legend {
	font-size: 15px;
	font-weight: bold;
	padding: 0 0 10px;
}
div.bbp-template-notice, div.indicator-hint {
    background: #f4f4f4;
    border: 1px solid #ddd;
    padding: 15px 20px;
    	-webkit-border-radius: 0px;
		-moz-border-radius: 0px;
    border-radius: 0px;
}
#bbpress-forums .wp-editor-container, 
#wp-bbp_topic_content-editor-container, 
#wp-bbp_reply_content-editor-container {
	border: 1px solid #ddd;
}
#wp-bbp_topic_content-editor-container textarea {
	background-color: transparent;
}
.bbp-topic-form input#bbp_topic_title, 
.bbp-topic-form input#bbp_topic_tags,
.bbp-topic-form select#bbp_stick_topic_select, 
.bbp-topic-form select#bbp_topic_status_select { 
	color: #AAA9A9;
	background-color: #ffffff;
    border: 1px solid #ddd;
		-webkit-box-shadow: 0 1px 5px rgba(0, 0, 0, 0.1) inset;  /* Safari 3-4, iOS 4.0.2 - 4.2, Android 2.3+ */
		-moz-box-shadow:    0 1px 5px rgba(0, 0, 0, 0.1) inset;  /* Firefox 3.5 - 3.6 */
	box-shadow:         	0 1px 5px rgba(0, 0, 0, 0.1) inset;  /* Opera 10.5, IE 9, Firefox 4+, Chrome 6+, iOS 5 */
    color: #747474;
    font-size: 13px;
    padding: 8px 2%;
}
.bbp-submit-wrapper button.submit {
	border: 1px solid #C69f70;
	background-color: #C69f70;
	color: #fff;
	padding: 8px 30px;
	font-size: 15px;
		-ms-transition: all 0.3s ease 0s;
		-moz-transition: all 0.3s ease 0s;
		-webkit-transition: all 0.3s ease 0s;
		-o-transition: all 0.3s ease 0s;
	transition: all 0.3s ease 0s;
}
.bbp-submit-wrapper button.submit:hover {
	background-color: #ddd;
	border: 1px solid #ccc;
	color: #666;
	cursor: pointer;
}
.bbp-search-form input[type="submit"] {
	display: inline-block;
	height: 45px;
	margin: 0px 0px 0px -4px;
}
div.bbp-template-notice, div.indicator-hint {
	color: #ed1c24;
}

@media only screen and (max-width: 480px) {
	.bbp-search-form input[type="submit"] {
		height: 29px;
	}
}

/* Woocommerce
================================================== */
.woocommerce #main .page-title {
	display: none;
}
.woocommerce-ordering .orderby {
	background-color: #fafafa;
	border: 1px solid rgba(0, 0, 0, 0.1);
	padding: 5px;
}
.woocommerce #respond input#submit, 
.woocommerce a.button, 
.woocommerce button.button, 
.woocommerce input.button {
	background-color: #C69f70;
	color: #fff;
		-webkit-border-radius: 3px;
		-moz-border-radius: 3px;
	border-radius: 3px;
	font-size: 14px;
	font-weight: 400;
		-ms-transition: all 0.3s ease 0s;
		-moz-transition: all 0.3s ease 0s;
		-webkit-transition: all 0.3s ease 0s;
		-o-transition: all 0.3s ease 0s;
	transition: all 0.3s ease 0s;
}
.woocommerce #respond input#submit.alt, 
.woocommerce a.button.alt, 
.woocommerce button.button.alt, 
.woocommerce input.button.alt {
	background-color: #C69f70;
	color: #fff;
		-ms-transition: all 0.3s ease 0s;
		-moz-transition: all 0.3s ease 0s;
		-webkit-transition: all 0.3s ease 0s;
		-o-transition: all 0.3s ease 0s;
	transition: all 0.3s ease 0s;
}	
.woocommerce #respond input#submit.alt:hover, 
.woocommerce a.button.alt:hover, 
.woocommerce button.button.alt:hover, 
.woocommerce input.button.alt:hover {
	background-color: #999;
	color: #fff;
}
.woocommerce .quantity .qty {
	height: 34px;
}
.woocommerce span.onsale {
	background-color: #2eb851;
	min-height: 4em;
	min-width: 4em;
	padding: 0.402em;
	font-size: 14px;
	left: -20px;
	top: -20px;
	font-weight: 500;
}
.woocommerce ul.products li.product .onsale {
	margin: -1em -1em 0 0;
}
.woocommerce ul.products li.product h3 {
	font-size: 1.2em;
}
.woocommerce ul.products li.product .price {
	font-size: 1em;
}
.woocommerce div.product p.price, 
.woocommerce div.product span.price {
	color: #747474;
}
.woocommerce ul.products li.product .price {
	color: #747474;
}
.woocommerce div.product .woocommerce-tabs .panel {
	padding-top: 20px;
}
.woocommerce-demo-store p.demo_store {
	background-color: #C69f70;
}
.woocommerce #content table.cart td.actions .input-text, 
.woocommerce table.cart td.actions .input-text, .woocommerce-page #content table.cart td.actions .input-text, 
.woocommerce-page table.cart td.actions .input-text {
	width: auto;
}
.woocommerce .woocommerce-message:before {
	color: #C69f70;
}
.woocommerce-cart table.cart td.actions .coupon .input-text {
	padding: 10px 6px 12px;
}
.woocommerce-cart .wc-proceed-to-checkout a.checkout-button {
	padding: 15px;
}
.woocommerce table.shop_table td {
	padding: 12px;
	border-top: 0px;
}
.woocommerce table.shop_table {
		-webkit-border-radius: 0px;
		-moz-border-radius: 0px;
	border-radius: 0px;
}
.woocommerce #reviews #comments ol.commentlist li .comment-text,
.woocommerce div.product .woocommerce-tabs ul.tabs li {
		-webkit-border-radius: 0px;
		-moz-border-radius: 0px;
	border-radius: 0px;
}
.woocommerce div.product .woocommerce-tabs ul.tabs li:after, 
.woocommerce div.product .woocommerce-tabs ul.tabs li:before {
	display: none;
}
.woocommerce nav.woocommerce-pagination ul li a, 
.woocommerce nav.woocommerce-pagination ul li span {
	padding: 0.5em 0.8em;
}
.woocommerce .woocommerce-ordering, 
.woocommerce .woocommerce-result-count {
	margin: 0 0 3em;
}
.woocommerce ul.products li.product a img {
	border: 1px solid #ddd;
	margin: 0px;
}
.woocommerce .widget_price_filter .ui-slider .ui-slider-range,
.woocommerce .widget_price_filter .ui-slider .ui-slider-handle {
	background-color: #2eb851;
}
.woocommerce .widget_price_filter .price_slider_wrapper .ui-widget-content {
	background-color: #008922;
}
.woocommerce .star-rating,
.comment-form-rating .stars span a {
	color: #f9b91e;
}
.woocommerce .woocommerce-product-search input.search-field {
	width: calc(100% - 95px);
}
.woocommerce .woocommerce-product-search input[type="submit"] {
	padding: 11px 20px 12px;
	border-radius: 0px;
}
.woocommerce .tagcloud a {
	border: 1px solid #ddd;
	padding: 5px 10px;
}
.woocommerce-review-link {
	color: #747474;
}
#main .woocommerce-MyAccount-navigation > ul {
	list-style: none;
}
.woocommerce-MyAccount-navigation ul li > a {
	border: 1px solid #e4e4e4;
	display: block;
	height: 100%;
	margin-bottom: -1px;
	padding: 8px;
	width: 100%;
}
.woocommerce-MyAccount-navigation ul li > a:hover,
.woocommerce-MyAccount-navigation ul li.is-active {
	background-color: #f8f8f8;
}
.related.products {
	display: inline-block;
}

