/**
 * Colors
 */
/**
 * Deprecated colors.
 * Please avoid using these.
 */
/**
 * Breakpoints & Media Queries
 */
/**
 * Colors
 */
/**
 * Deprecated colors.
 * Please avoid using these.
 */
/**
 * Fonts & basic variables.
 */
/**
 * Grid System.
 * https://make.wordpress.org/design/2019/10/31/proposal-a-consistent-spacing-system-for-wordpress/
 */
/**
 * Dimensions.
 */
/**
 * Shadows.
 */
/**
 * Editor widths.
 */
/**
 * Block UI.
 */
/**
 * Border radii.
 */
/**
 * Breakpoint mixins
 */
/**
 * Long content fade mixin
 *
 * Creates a fading overlay to signify that the content is longer
 * than the space allows.
 */
/**
 * Focus styles.
 */
/**
 * Applies editor left position to the selector passed as argument
 */
/**
 * Styles that are reused verbatim in a few places
 */
/**
 * Allows users to opt-out of animations via OS-level preferences.
 */
/**
 * Reset default styles for JavaScript UI based pages.
 * This is a WP-admin agnostic reset
 */
/**
 * Reset the WP Admin page styles for Gutenberg-like pages.
 */
:root {
  --wp-admin-theme-color: #007cba;
  --wp-admin-theme-color-darker-10: #006ba1;
  --wp-admin-theme-color-darker-20: #005a87; }

#start-resizable-editor-section {
  display: none; }

.wp-block-audio figcaption {
  color: #555d66;
  font-size: 13px;
  text-align: center; }

.wp-block-code {
  font-family: Menlo, Consolas, monaco, monospace;
  font-size: 15px;
  color: #1e1e1e;
  padding: 0.8em 1em;
  border: 1px solid #ddd;
  border-radius: 4px; }

.wp-block-embed figcaption {
  color: #555d66;
  font-size: 13px;
  text-align: center; }

.blocks-gallery-caption {
  color: #555d66;
  font-size: 13px;
  text-align: center; }

.wp-block-image figcaption {
  color: #555d66;
  font-size: 13px;
  text-align: center; }

.wp-block-pullquote {
  border-top: 4px solid #555d66;
  border-bottom: 4px solid #555d66;
  margin-bottom: 28px;
  color: #40464d; }
  .wp-block-pullquote cite,
  .wp-block-pullquote footer, .wp-block-pullquote__citation {
    color: #40464d;
    text-transform: uppercase;
    font-size: 13px;
    font-style: normal; }

.wp-block-navigation ul,
.wp-block-navigation ul li {
  list-style: none; }

.wp-block-navigation-link.wp-block-navigation-link {
  margin: 0; }

.wp-block-quote {
  border-right: 4px solid #000;
  margin: 0 0 28px 0;
  padding-right: 1em; }
  .wp-block-quote cite,
  .wp-block-quote footer, .wp-block-quote__citation {
    color: #6c7781;
    font-size: 13px;
    margin-top: 1em;
    position: relative;
    font-style: normal; }
  .wp-block-quote.has-text-align-right, .wp-block-quote.has-text-align-right {
    border-right: none;
    border-left: 4px solid #000;
    padding-right: 0;
    padding-left: 1em; }
  .wp-block-quote.has-text-align-center, .wp-block-quote.has-text-align-center {
    border: none;
    padding-right: 0; }
  .wp-block-quote.is-style-large, .wp-block-quote.is-large {
    border: none; }

.wp-block-search .wp-block-search__label {
  font-weight: bold; }

.wp-block-group.has-background {
  padding: 20px 30px;
  margin-top: 0;
  margin-bottom: 0; }

.wp-block-separator {
  border: none;
  border-bottom: 2px solid #8f98a1;
  margin-right: auto;
  margin-left: auto; }
  .wp-block-separator:not(.is-style-wide):not(.is-style-dots) {
    max-width: 100px; }
  .wp-block-separator.has-background:not(.is-style-dots) {
    border-bottom: none;
    height: 1px; }
  .wp-block-separator.has-background:not(.is-style-wide):not(.is-style-dots) {
    height: 2px; }

.wp-block-table {
  border-collapse: collapse; }
  .wp-block-table thead {
    border-bottom: 3px solid; }
  .wp-block-table tfoot {
    border-top: 3px solid; }
  .wp-block-table td,
  .wp-block-table th {
    padding: 0.5em;
    border: 1px solid;
    word-break: normal; }
  .wp-block-table figcaption {
    color: #555d66;
    font-size: 13px;
    text-align: center; }

.wp-block-video figcaption {
  color: #555d66;
  font-size: 13px;
  text-align: center; }

#end-resizable-editor-section {
  display: none; }
