/* Viewport Size 979px */
@media screen and ( max-width: 979px ) {

  .header-logo a {
    font-size: 80px !important;
    line-height: 1 !important;
  }

  .site-description {
    font-size: 13px !important; 
  }

  #top-bar > div,
  #main-nav > div,
  #featured-links,
  .main-content,
  .page-footer-inner,
  .featured-slider-area.boxed-wrapper {
    padding-left: 30px;
    padding-right: 30px;
  }

  .slider-item-bg,
  #featured-slider.boxed-wrapper .slider-item-bg {
    height: 500px;
  }

  #top-menu,
  top-menu-container,
  .main-menu-container,
  #main-menu {
    display: none;
  }

  .mobile-menu-btn {
    display: inline-block;
  }

  .main-nav-buttons {
    position: absolute;
    top: 0px;
    left: 30px;
    z-index: 1;
    float: none;
    margin: 0;
  }
        
  .main-nav-icons {
    position: absolute;
    top: 0px;
    right: 30px;
    z-index: 2;
    float: none;
    margin: 0;
  }

  #main-nav {
    text-align: center !important;
  }

  .main-container {
    width: 100% !important;
    margin: 0 !important;
  }

  .sidebar-left,
  .sidebar-right {
    width: 100% !important;
    padding: 0 !important;
    margin-top: 40px;
  }

  .sidebar-left-wrap,
  .sidebar-right-wrap,
  .footer-widgets .bard-widget {
    float: none !important;
    width: 65% !important;
    margin-left: auto !important;
    margin-right: auto !important;
  }

  .featured-slider-area.boxed-wrapper {
    padding: 0 !important;
  }

  .footer-socials a {
    margin-right: 10px;
  }

  .footer-socials a span:last-child {
    display: none;
  }

}


/* Viewport Size 768px */
@media screen and ( max-width: 768px ) {

  .slider-item-bg,
  #featured-slider.boxed-wrapper .slider-item-bg {
    height: 360px;
  }

  #featured-slider .slick-arrow,
  .slider-content {
    display: none !important;
  }

  .slider-categories {
    margin-bottom: 8px !important;
    letter-spacing: 1px;
    font-size: 10px !important;
  }

  .slider-dots li {
    width: 11px;
    height: 11px;
    margin-right: 7px;
  }

  #featured-links {
    display: none;
  }

  .comments-area {
    margin-bottom: 50px;
  }

  .comment-form-author input,
  .comment-form-email input, 
  .comment-form-url input,
  .wpcf7 input[type="text"],
  .wpcf7 input[type="email"],
  .wpcf7 input[type="url"] {
    width: 100% !important;
  }

  .previous-post > a,
  .next-post > a {
    display: none;
  }

  .comment-avatar {
    display: none;
  }

  .comments-area .children {
    margin-left: 15px;
  }

  .comment-form-author,
  .comment-form-email,
  .comment-form-url {
    width: 100%;
  }

}


/* Viewport Size 640px */
@media screen and ( max-width: 640px ) {

  .slider-item-bg,
  #featured-slider.boxed-wrapper .slider-item-bg {
    height: 330px;
  }

  .slider-dots {
    bottom: 14px;
  }

  .related-posts section {
    width: 100%;
    margin: 0 0 25px 0;
  }

  .sidebar-left-wrap,
  .sidebar-right-wrap,
  .related-posts section img,
  .footer-widgets .bard-widget {
    width: 100% !important;
  }

  #page-header .entry-header {
    height: auto;
    padding: 70px 0;
  }

  .header-logo {
    padding-top: 0 !important;
  }

  .header-logo a {
    font-size: 45px !important;
    line-height: 1 !important;
  }

  .blog-grid > li {
    width: 100% !important;
    margin-right: 0 !important;
  }

  .blog-list-style .post-media,
  .blog-list-style .post-content-wrap {
    float: none !important;
    width: 100% !important;
    padding: 0 !important;
  }

  .blog-list-style .post-media {
    margin: 0 auto 20px auto;
  }

  .blog-grid .post-header,
  .blog-grid .read-more,
  .blog-list-style .post-content-wrap {
    text-align: center !important;
  } 
  
  .footer-copyright .copyright-info,
  .footer-copyright .credit,
  .footer-copyright .footer-socials {
    width: 100%;
    float: none;
    text-align: center;
  }

  .footer-copyright .footer-socials {
    margin-top: 12px;
  }

  .sidebar-alt {
    padding-left: 20px !important;
    padding-right: 20px !important;
  }

  .sticky {
    padding: 20px !important;
  }

  .slider-info {
    padding: 10px;
  }

  .post-slider .prev-arrow,
  .post-slider .next-arrow {
    padding: 0 10px !important;
    margin-top: -14px!important;
    font-size: 30px !important;
  }

  .post-content > p:first-of-type:first-letter {
    font-family: inherit !important;
    float: none !important;
    margin: 0 !important;
    font-size: inherit !important;
    line-height: inherit !important;
    text-align: inherit !important;
    text-transform: inherit !important;
    color: inherit !important;
  }

}


/* Viewport Size 480px */
@media screen and ( max-width: 480px ) {

  #top-bar > div,
  #main-nav > div,
  .main-content,
  .page-footer-inner {
    padding-left: 20px !important;
    padding-right: 20px !important;
  }

  .slider-item-bg,
  #featured-slider.boxed-wrapper .slider-item-bg {
    height: 280px;
  }

  .slider-title {
    font-size: 28px;
    line-height: 38px;
    margin-bottom: 18px;
  }

  .slider-title:after {
    display: none;
  }

  #featured-links h6 {
    padding: 5px 10px;
    font-size: 9px !important;
    letter-spacing: 0 !important;
  }

  .post-title,
  .page-title {
    font-size: 33px;
    line-height: 38px !important;
  }

  .main-nav-buttons {
    left: 20px !important;
  }
  
  .main-nav-icons {
    right: 20px !important;
  }

  .comment-reply-link {
    display: block;
    float: none;
    margin: 0;
  }

  .single-navigation .previous-post,
  .single-navigation .next-post {
    width: 100%;
  }

  .single-navigation .previous-post > div,
  .single-navigation .next-post > div {
    float: none;
    text-align: center;
  }

}

/* Viewport Size 320px */
@media screen and ( max-width: 320px ) {
  
  .post-content {
    text-align: left;
  }

}

/* Wp def gallery */
@media screen and ( min-width: 950px ) {

  .gallery-columns-2 .gallery-item:nth-child(2n+2),
  .gallery-columns-3 .gallery-item:nth-child(3n+3),
  .gallery-columns-4 .gallery-item:nth-child(4n+4),
  .gallery-columns-5 .gallery-item:nth-child(5n+5),
  .gallery-columns-6 .gallery-item:nth-child(6n+6),
  .gallery-columns-7 .gallery-item:nth-child(7n+7),
  .gallery-columns-8 .gallery-item:nth-child(8n+8),
  .gallery-columns-9 .gallery-item:nth-child(9n+9) {
    margin-right: 0 !important;
  }

  .gallery-columns-2 .gallery-item:nth-child(2n+2) + li,
  .gallery-columns-3 .gallery-item:nth-child(3n+3) + li,
  .gallery-columns-4 .gallery-item:nth-child(4n+4) + li,
  .gallery-columns-5 .gallery-item:nth-child(5n+5) + li,
  .gallery-columns-6 .gallery-item:nth-child(6n+6) + li,
  .gallery-columns-7 .gallery-item:nth-child(7n+7) + li,
  .gallery-columns-8 .gallery-item:nth-child(8n+8) + li,
  .gallery-columns-9 .gallery-item:nth-child(9n+9) + li {
    clear: both;
  }

}


@media screen and ( max-width: 950px ) {

  .gallery-item {
    width: -webkit-calc((100% - (5px * 1)) / 2 - 1px) !important;
    width: calc((100% - (5px * 1)) / 2 - 1px) !important;
  }

  .gallery-item:nth-child(2n+2) {
    margin-right: 0 !important;
  }

  .gallery-columns-1 .gallery-item {
    width: 100% !important;
  }

}


@media screen and ( max-width: 480px ) {

  .gallery-item {
    width: 100% !important;
    float: none !important;
  }

}


/* WooCommerce */
@media screen and ( max-width: 768px ) {

  .woocommerce #page-content ul.products li.product,
  .woocommerce-page #page-content ul.products li.product,
  .woocommerce-page[class*=columns-] #page-content ul.products li.product,
  .woocommerce[class*=columns-] #page-content ul.products li.product {
    width: 48%;
    float: left;
    clear: both;
  }

  .woocommerce .woocommerce-checkout-review-order table.shop_table,
  .woocommerce-checkout-review-order .woocommerce-checkout-payment,
  .woocommerce .cart-collaterals .cross-sells ul.products li,
  .woocommerce-page .cart-collaterals .cross-sells ul.products li{
    float: none;
    width: 100%;
  }

  .woocommerce-account .woocommerce-MyAccount-navigation {
    width: 100%;
    margin-bottom: 40px;
  }

  .woocommerce ul.products li:nth-child(odd),
  .woocommerce-page ul.products li:nth-child(odd) {
    margin-right: 4% !important;
  }


  .woocommerce ul.products li:nth-child(even),
  .woocommerce-page ul.products li:nth-child(even) {
    margin-right: 0 !important;
  }

  .woocommerce .woocommerce-checkout-review-order table.shop_table,
  .woocommerce-checkout-review-order .woocommerce-checkout-payment {
    float: none !important;
    width: 100% !important;
  }

}


@media screen and ( max-width: 640px ) {

  .woocommerce #page-content ul.products li.product,
  .woocommerce-page #page-content ul.products li.product,
  .woocommerce-page[class*=columns-] #page-content ul.products li.product,
  .woocommerce[class*=columns-] #page-content ul.products li.product {
    width: 100% !important;
    float: none;
    clear: both;
  }

  .woocommerce-page table.cart td.actions .coupon .input-text {
    margin-bottom: 7px;
  }

  .woocommerce-page table.cart td.actions .coupon .input-text+.button {
    display: block;
    float: none !important;
  }

  .woocommerce .woocommerce-ordering {
    float: left;
    margin-bottom: 25px;
  }

  .woocommerce .woocommerce-result-count,
  .woocommerce-page .woocommerce-result-count {
    float: none;
  }
      
}


/* Page Header */
@media screen and (max-width: 1280px) {
     .entry-header {
         height: 430px !important;
    }
}
 @media screen and (max-width: 1080px) {
     .entry-header {
         height: 350px !important;
    }
}
 @media screen and (max-width: 880px) {
     .entry-header {
         height: 290px !important;
    }
     .logo-img {
         max-width: 300px !important;
    }
}
 @media screen and (max-width: 750px) {
     .entry-header {
         height: 250px !important;
    }
     .logo-img {
         max-width: 250px !important;
    }
}
 @media screen and (max-width: 690px) {
     .entry-header {
         height: 210px !important;
    }
     .logo-img {
         max-width: 200px !important;
    }
}
 @media screen and (max-width: 550px) {
     .entry-header {
         height: auto !important;
         padding: 50px 0 !important;
    }
}


/* Featured Links */
@media screen and (max-width: 768px) {
     #featured-links {
         padding: 7px 16px !important;
    }
}
 @media screen and (max-width: 768px) {
     #featured-links h6 {
         padding: 7px 16px !important;
         font-size: 13px !important;
    }
}
 @media screen and (max-width: 640px) {
     #featured-links h6 {
         padding: 5px 13px !important;
         font-size: 12px !important;
    }
}
@media screen and (max-width: 640px) {
     #featured-links h6 {
         padding: 4px 10px !important;
         font-size: 10px !important;
    }
}