jQuery(window).load(function(){var e=edge_slider_value.transition_effect,t=edge_slider_value.transition_delay,i=edge_slider_value.transition_duration;jQuery(".layer-slider").cycle({timeout:t,fx:e,activePagerClass:"active",pager:".slider-button",pause:1,pauseOnPagerHover:1,width:"100%",containerResize:0,fit:1,next:"#next2",prev:"#prev2",speed:i,after:function(){jQuery(this).parent().css("height",jQuery(this).height())},cleartypeNoBg:!0})});
