/*************** 10. Multi fields ***************/
.customize_multi_fields .set{
	margin-bottom: 5px;
	padding-right: 15px;
	position: relative;
}

.customize_multi_fields input{
	margin-bottom: 5px!important;
}

.customize_multi_remove_field{
	color: red;
	position: absolute;
	right: -7px;
	top: 3px;
}

.customize_multi_remove_field span{
	text-decoration: none;
}

.customize_multi_remove_field:active,
.customize_multi_remove_field:focus{
	outline: none;
	-webkit-box-shadow: none;
	box-shadow: none;
}

/**
 * SWITCH CONTROL *
 */
.onoffswitch {
    position: relative;
    width: 100px;
    margin-right: 15px;
    overflow: hidden;
    cursor: pointer;
}

.onoffswitch-inner {
    width: 200%;
    margin-left: -100%;
    -moz-transition: margin .3s ease-in 0s;
    -webkit-transition: margin .3s ease-in 0s;
    -o-transition: margin .3s ease-in 0s;
    transition: margin .3s ease-in 0s
}

.onoffswitch-inner > div {
    float: left;
    position: relative;
    width: 50%;
    height: 24px;
    padding: 0;
    line-height: 24px;
    font-size: 12px;
    color: #fff;
    font-weight: 700;
    -moz-box-sizing: border-box;
    -webkit-box-sizing: border-box;
    box-sizing: border-box
}

.onoffswitch-inner .onoffswitch-active {
    background-color: #d4d4d4;
    color: #FFF
}

.onoffswitch-inner .onoffswitch-inactive {
    background-color: #d4d4d4;
    color: #FFF;
    text-align: right
}

.onoffswitch-switch {
    width: 50px;
    margin: 0;
    text-align: center;
    border: 0 solid #999;
    border-radius: 0;
    position: absolute;
    top: 0;
    bottom: 0
}

.onoffswitch-active .onoffswitch-switch {
    background: #0073aa;
    left: 0
}

.onoffswitch-inactive .onoffswitch-switch {
    background: #7D7D7D;
    right: 0
}
.switch-on .onoffswitch-inner {
    margin-left: 0
}

/*CHOSEN*/
.chosen-container-single .chosen-single {
    border-radius: 0px;
    height: 28px;
    background: #FFF;
    border-color: #DDDDDD;
    line-height: 28px;
    -webkit-box-shadow: inset 0px 1px 1px rgba(0,0,0,0.06);
    box-shadow: inset 0px 1px 1px rgba(0,0,0,0.06);
}

.chosen-container-single .chosen-single div b{
    background-position: 0px 4px;
}

.chosen-container-active.chosen-with-drop .chosen-single div b {
    background-position: -18px 4px;
}

.chosen-container-multi .chosen-choices li{
    float: none;
}

/* === Radio Image Control === */

.customize-control-radio-image input[type="radio"] {
    clip:     rect(1px, 1px, 1px, 1px);
    height:   1px;
    overflow: hidden;
    position: absolute !important;
    width:    1px;
}

.customize-control-radio-image img {
    box-sizing: border-box;
    max-width:  100%;
    height:     auto;
    padding:    1px;
    border:     4px solid transparent;
}

.customize-control-radio-image img:hover,
.customize-control-radio-image img:focus {
    border-color: #ccc;
}

.customize-control-radio-image input:checked + img {
    border-color: #00a0d2;
}