/************************* alternative CUSTOMIZER CUSTOM CSS **************************************/
.wp-core-ui .btn-upgrade, #about_alternative {
	background-color: #7eab9f;
	border: 1px solid #7eab9f;
	box-shadow: none;
	color: #fff;
	margin-top: 10px;
	border-radius: 0;
		-ms-transition: all 0.3s ease 0s;
		-moz-transition: all 0.3s ease 0s;
		-webkit-transition: all 0.3s ease 0s;
		-o-transition: all 0.3s ease 0s;
	transition: all 0.3s ease 0s;
}
.wp-core-ui .btn-upgrade:hover, #about_alternative:hover,
.wp-core-ui .btn-upgrade:focus, #about_alternative:focus  {
	background-color: #bbb;
	border: 1px solid #bbb;
	box-shadow: none;
	color: #fff;
}
#alternative_upgrade{
	display: block;
	float: left;
	width: 100%;
}
#about_alternative{
	display: block;
	padding: 10px 0px 10px 0;
	text-align: center;
	margin: -5px;
}
#customize-controls .control-section-alternative .accordion-section-title:hover,
#customize-controls .control-section-alternative .accordion-section-title:focus {
	background-color: #fff;
}

.control-section-alternative .accordion-section-title .button {
	margin-top:  -4px;
	font-weight: 400;
	margin-left: 8px;
}

	.rtl .control-section-alternative .accordion-section-title .button {
		margin-left:  0;
		margin-right: 8px;
	}