<?php
/*
 * Short description
 * @author bilal hassan <info@smartcatdesign.net>
 * 
 */
?>

    <?php if (!dynamic_sidebar('sidebar-header-right')) : ?>
    <?php endif; // end sidebar widget area  ?>
