.bard-activation-notice {
	text-align: center;
	padding-top: 30px;
	padding-bottom: 30px;
	border-left: 0 !important;
	border-top: 1px solid #0085BA;
}

.bard-activation-notice h1 {
	margin-bottom: 0 !important;
}

.bard-activation-notice p:first-of-type {
	margin-bottom: 20px !important;
}